/* SPDX-License-Identifier: GPL-2.0 */
#ifndef __DT_BINDINGS_Q6_AFE_H__
#define __DT_BINDINGS_Q6_AFE_H__

/* This file exists due to backward compatibility reasons, Please do not DELETE! */

#include <dt-bindings/sound/qcom,q6dsp-lpass-ports.h>

#endif /* __DT_BINDINGS_Q6_AFE_H__ */
