/*
 * Automatically generated file; DO NOT EDIT.
 * Linux/arm64 6.6.40 Kernel Configuration
 */
#define CONFIG_COMMON_CLK_SCMI 1
#define CONFIG_HAVE_ARCH_SECCOMP_FILTER 1
#define CONFIG_SND_PROC_FS 1
#define CONFIG_SCSI_DMA 1
#define CONFIG_NETFILTER_FAMILY_BRIDGE 1
#define CONFIG_CC_HAS_SANCOV_TRACE_PC 1
#define CONFIG_DEFAULT_INIT ""
#define CONFIG_ARM64_PAGE_SHIFT 12
#define CONFIG_ARCH_HAS_DEBUG_VM_PGTABLE 1
#define CONFIG_INPUT_KEYBOARD 1
#define CONFIG_INET_TABLE_PERTURB_ORDER 16
#define CONFIG_ARCH_SUPPORTS_INT128 1
#define CONFIG_MEMORY_ISOLATION 1
#define CONFIG_SLUB_CPU_PARTIAL 1
#define CONFIG_RFS_ACCEL 1
#define CONFIG_ARCH_WANTS_THP_SWAP 1
#define CONFIG_CRC32 1
#define CONFIG_ARCH_INLINE_READ_LOCK_IRQ 1
#define CONFIG_I2C_BOARDINFO 1
#define CONFIG_PNFS_FLEXFILE_LAYOUT 1
#define CONFIG_SECCOMP 1
#define CONFIG_PCI_ECAM 1
#define CONFIG_HIGH_RES_TIMERS 1
#define CONFIG_ARCH_HAS_SET_MEMORY 1
#define CONFIG_VLAN_8021Q 1
#define CONFIG_XEN_DOM0 1
#define CONFIG_BT_RFCOMM 1
#define CONFIG_FIX_EARLYCON_MEM 1
#define CONFIG_LEDS_TRIGGER_HEARTBEAT 1
#define CONFIG_XLNX_SEC_CFG 1
#define CONFIG_INOTIFY_USER 1
#define CONFIG_HDMI 1
#define CONFIG_XLNX_EVENT_MANAGER 1
#define CONFIG_BRIDGE_EBT_T_FILTER_MODULE 1
#define CONFIG_NETWORK_FILESYSTEMS 1
#define CONFIG_MODULE_FORCE_UNLOAD 1
#define CONFIG_SATA_AHCI_PLATFORM 1
#define CONFIG_ARM64_VA_BITS 48
#define CONFIG_AMD_PHY 1
#define CONFIG_BT_HCIBFUSB 1
#define CONFIG_FB_CORE 1
#define CONFIG_GLOB 1
#define CONFIG_ARCH_WANT_LD_ORPHAN_WARN 1
#define CONFIG_SERIAL_UARTLITE_CONSOLE 1
#define CONFIG_CGROUP_DEVICE 1
#define CONFIG_DRM_ZYNQMP_DPSUB 1
#define CONFIG_ARM64_CNP 1
#define CONFIG_DMA_BOUNCE_UNALIGNED_KMALLOC 1
#define CONFIG_ARCH_SUSPEND_POSSIBLE 1
#define CONFIG_MMU_LAZY_TLB_REFCOUNT 1
#define CONFIG_COMPAT_NETLINK_MESSAGES 1
#define CONFIG_INLINE_WRITE_UNLOCK_IRQ 1
#define CONFIG_USB_G_SERIAL_MODULE 1
#define CONFIG_CGROUP_WRITEBACK 1
#define CONFIG_MAC80211_STA_HASH_MAX_SIZE 0
#define CONFIG_GPIO_ZYNQMP_MODEPIN 1
#define CONFIG_HAVE_ARCH_MMAP_RND_BITS 1
#define CONFIG_TCG_TIS_CORE 1
#define CONFIG_PHY_XILINX_ZYNQMP 1
#define CONFIG_XILINX_TSN_QCI 1
#define CONFIG_ARM64_ERRATUM_1024718 1
#define CONFIG_EXT4_FS_POSIX_ACL 1
#define CONFIG_NET_SWITCHDEV 1
#define CONFIG_PHYLINK 1
#define CONFIG_ZSTD_COMPRESS 1
#define CONFIG_SSB_POSSIBLE 1
#define CONFIG_NFS_V4_2 1
#define CONFIG_BRIDGE_EBT_T_NAT_MODULE 1
#define CONFIG_USB_F_EEM 1
#define CONFIG_MMU_NOTIFIER 1
#define CONFIG_ASYMMETRIC_KEY_TYPE 1
#define CONFIG_TRANSPARENT_HUGEPAGE_MADVISE 1
#define CONFIG_SPI_DYNAMIC 1
#define CONFIG_ARCH_CORRECT_STACKTRACE_ON_KRETPROBE 1
#define CONFIG_MTD_CMDLINE_PARTS 1
#define CONFIG_IP_NF_NAT_MODULE 1
#define CONFIG_ZYNQMP_IPI_MBOX 1
#define CONFIG_BME680_SPI 1
#define CONFIG_BRIDGE_NF_EBTABLES_MODULE 1
#define CONFIG_CRYPTO_SHA1_ARM64_CE 1
#define CONFIG_USB_OHCI_LITTLE_ENDIAN 1
#define CONFIG_NET_SCH_FIFO 1
#define CONFIG_SWPHY 1
#define CONFIG_IOMMU_IO_PGTABLE_LPAE 1
#define CONFIG_THP_SWAP 1
#define CONFIG_FSNOTIFY 1
#define CONFIG_BLK_DEV_LOOP_MIN_COUNT 8
#define CONFIG_STP 1
#define CONFIG_SPI_CADENCE 1
#define CONFIG_MEDIA_ATTACH 1
#define CONFIG_NET_PTP_CLASSIFY 1
#define CONFIG_UNIX_DIAG 1
#define CONFIG_GENERIC_SMP_IDLE_THREAD 1
#define CONFIG_NET_VENDOR_QUALCOMM 1
#define CONFIG_ARCH_SUPPORTS_NUMA_BALANCING 1
#define CONFIG_ARCH_SUPPORTS_CRASH_DUMP 1
#define CONFIG_NET_VENDOR_EZCHIP 1
#define CONFIG_XEN_COMPAT_XENFS 1
#define CONFIG_DEFAULT_SECURITY_DAC 1
#define CONFIG_MEDIA_DIGITAL_TV_SUPPORT 1
#define CONFIG_LDISC_AUTOLOAD 1
#define CONFIG_CRYPTO_CRCT10DIF 1
#define CONFIG_CRYPTO_GHASH_ARM64_CE 1
#define CONFIG_USB_AUTOSUSPEND_DELAY 2
#define CONFIG_IP6_NF_MANGLE 1
#define CONFIG_HAVE_IRQ_TIME_ACCOUNTING 1
#define CONFIG_BT_MRVL_SDIO 1
#define CONFIG_BT_HCIBPA10X 1
#define CONFIG_IPV6 1
#define CONFIG_HAVE_STACKPROTECTOR 1
#define CONFIG_NET_9P 1
#define CONFIG_NET_HANDSHAKE 1
#define CONFIG_CRYPTO_AEAD 1
#define CONFIG_VIDEO_XILINX_AXI4S_BROADCASTER 1
#define CONFIG_COMPAT 1
#define CONFIG_MAGIC_SYSRQ_SERIAL 1
#define CONFIG_BQL 1
#define CONFIG_DEFAULT_TCP_CONG "cubic"
#define CONFIG_USB_UAS 1
#define CONFIG_DEVTMPFS 1
#define CONFIG_OF_IOMMU 1
#define CONFIG_PNFS_FILE_LAYOUT 1
#define CONFIG_CDX_BUS 1
#define CONFIG_RPMSG_VIRTIO_BUF_SIZE 512
#define CONFIG_SUNRPC_BACKCHANNEL 1
#define CONFIG_VIDEO_XILINX_DEMOSAIC 1
#define CONFIG_IP6_NF_TARGET_REJECT 1
#define CONFIG_CPUFREQ_DT 1
#define CONFIG_ARCH_MMAP_RND_COMPAT_BITS_MAX 16
#define CONFIG_ARCH_SPARSEMEM_ENABLE 1
#define CONFIG_DRM_XLNX_HDCP 1
#define CONFIG_HOTPLUG_CPU 1
#define CONFIG_SND_SOC_GENERIC_DMAENGINE_PCM 1
#define CONFIG_WLAN 1
#define CONFIG_NAMESPACES 1
#define CONFIG_HAVE_CMPXCHG_DOUBLE 1
#define CONFIG_ARCH_USE_MEMREMAP_PROT 1
#define CONFIG_NFS_V4_2_READ_PLUS 1
#define CONFIG_HAVE_ARCH_HUGE_VMAP 1
#define CONFIG_FRAMEBUFFER_CONSOLE_DETECT_PRIMARY 1
#define CONFIG_DRM_GEM_DMA_HELPER 1
#define CONFIG_USB_CONFIGFS 1
#define CONFIG_INLINE_SPIN_UNLOCK_BH 1
#define CONFIG_BLK_DEV_BSG 1
#define CONFIG_CONNECTOR 1
#define CONFIG_MEDIA_USB_SUPPORT 1
#define CONFIG_CRYPTO_ARCH_HAVE_LIB_CHACHA 1
#define CONFIG_DVB_MAX_ADAPTERS 16
#define CONFIG_LEGACY_PTYS 1
#define CONFIG_CRYPTO_DRBG_MENU 1
#define CONFIG_CRYPTO_RNG2 1
#define CONFIG_PHY_XILINX_HDMIPHY 1
#define CONFIG_MSDOS_FS 1
#define CONFIG_USB_U_SERIAL 1
#define CONFIG_NET_CLS_CGROUP_MODULE 1
#define CONFIG_TUN_MODULE 1
#define CONFIG_WLAN_VENDOR_MICROCHIP 1
#define CONFIG_NET_VENDOR_DAVICOM 1
#define CONFIG_SOFTIRQ_ON_OWN_STACK 1
#define CONFIG_IIO_KFIFO_BUF 1
#define CONFIG_SPI_CADENCE_QUADSPI 1
#define CONFIG_ARCH_ENABLE_THP_MIGRATION 1
#define CONFIG_CAN 1
#define CONFIG_CFG80211_MODULE 1
#define CONFIG_PAGE_SIZE_LESS_THAN_256KB 1
#define CONFIG_ARCH_INLINE_SPIN_LOCK_IRQ 1
#define CONFIG_OF_RESERVED_MEM 1
#define CONFIG_SERIAL_8250 1
#define CONFIG_XEN_GNTDEV_MODULE 1
#define CONFIG_CAVIUM_ERRATUM_30115 1
#define CONFIG_LZO_DECOMPRESS 1
#define CONFIG_IOMMU_SUPPORT 1
#define CONFIG_VFIO_IOMMU_TYPE1 1
#define CONFIG_LEDS_TRIGGER_CAMERA 1
#define CONFIG_ARM64_ERRATUM_2077057 1
#define CONFIG_WLAN_VENDOR_CISCO 1
#define CONFIG_ARM64_USE_LSE_ATOMICS 1
#define CONFIG_CRAMFS_BLOCKDEV 1
#define CONFIG_NFSD 1
#define CONFIG_COMPAT_BINFMT_ELF 1
#define CONFIG_GCC_SUPPORTS_DYNAMIC_FTRACE_WITH_ARGS 1
#define CONFIG_EDAC_XILINX_XILSEM 1
#define CONFIG_VERSAL_SYSMON 1
#define CONFIG_RD_LZMA 1
#define CONFIG_USB 1
#define CONFIG_I2C_XILINX 1
#define CONFIG_MODULES_USE_ELF_RELA 1
#define CONFIG_CRYPTO_HMAC 1
#define CONFIG_WLAN_VENDOR_REALTEK 1
#define CONFIG_ETHERNET 1
#define CONFIG_JFFS2_LZO 1
#define CONFIG_CRYPTO_SHA3 1
#define CONFIG_UBIFS_FS_ZSTD 1
#define CONFIG_VIDEO_IMX274 1
#define CONFIG_HAVE_DMA_CONTIGUOUS 1
#define CONFIG_DQL 1
#define CONFIG_VXLAN_MODULE 1
#define CONFIG_FRAMEBUFFER_CONSOLE 1
#define CONFIG_SOCK_CGROUP_DATA 1
#define CONFIG_COREDUMP 1
#define CONFIG_RESET_SCMI 1
#define CONFIG_JFFS2_COMPRESSION_OPTIONS 1
#define CONFIG_BCMA_POSSIBLE 1
#define CONFIG_USB_CONFIGFS_RNDIS 1
#define CONFIG_CC_HAS_AUTO_VAR_INIT_ZERO 1
#define CONFIG_SATA_HOST 1
#define CONFIG_SND_SOC 1
#define CONFIG_SCSI_COMMON 1
#define CONFIG_SURFACE_PLATFORMS 1
#define CONFIG_PRINTK 1
#define CONFIG_JFFS2_RUBIN 1
#define CONFIG_FB_SYS_FILLRECT 1
#define CONFIG_TIMERFD 1
#define CONFIG_CRYPTO_LIB_CHACHA_GENERIC 1
#define CONFIG_DNS_RESOLVER 1
#define CONFIG_MTD_CFI_I2 1
#define CONFIG_AT803X_PHY 1
#define CONFIG_XILINX_DMA 1
#define CONFIG_CFG80211_REG_RELAX_NO_IR 1
#define CONFIG_VIDEO_V4L2_SUBDEV_API 1
#define CONFIG_ARCH_HAS_SYSCALL_WRAPPER 1
#define CONFIG_ARCH_INLINE_SPIN_LOCK_BH 1
#define CONFIG_COMPAT_32BIT_TIME 1
#define CONFIG_SHMEM 1
#define CONFIG_MTD 1
#define CONFIG_MIGRATION 1
#define CONFIG_HAVE_ARCH_JUMP_LABEL 1
#define CONFIG_BUILD_SALT ""
#define CONFIG_MMC_BLOCK_MINORS 8
#define CONFIG_HAVE_ARCH_PREL32_RELOCATIONS 1
#define CONFIG_DECOMPRESS_LZMA 1
#define CONFIG_SENSORS_IIO_HWMON 1
#define CONFIG_DEVTMPFS_MOUNT 1
#define CONFIG_HAVE_PREEMPT_DYNAMIC 1
#define CONFIG_DNOTIFY 1
#define CONFIG_AS_HAS_ARMV8_3 1
#define CONFIG_USB_DWC3_XILINX 1
#define CONFIG_VIDEO_XILINX_HDCP1X_RX 1
#define CONFIG_SCSI_UFSHCD 1
#define CONFIG_GENERIC_NET_UTILS 1
#define CONFIG_ATA 1
#define CONFIG_MTD_TESTS_MODULE 1
#define CONFIG_USB_ROLE_SWITCH 1
#define CONFIG_GPIOLIB_FASTPATH_LIMIT 512
#define CONFIG_REMOTEPROC 1
#define CONFIG_NLS_CODEPAGE_437 1
#define CONFIG_ARCH_PROC_KCORE_TEXT 1
#define CONFIG_EXPORTFS 1
#define CONFIG_MTD_UBI_WL_THRESHOLD 4096
#define CONFIG_I2C_SLAVE_EEPROM 1
#define CONFIG_NET_INGRESS 1
#define CONFIG_PCIE_XILINX_NWL 1
#define CONFIG_HAVE_FUNCTION_ERROR_INJECTION 1
#define CONFIG_GPIO_ZYNQ 1
#define CONFIG_ARM64_ERRATUM_1286807 1
#define CONFIG_ARM_GIC 1
#define CONFIG_OLD_SIGSUSPEND3 1
#define CONFIG_SERIO 1
#define CONFIG_FB_SYS_IMAGEBLIT 1
#define CONFIG_SUNRPC_GSS 1
#define CONFIG_CORE_DUMP_DEFAULT_ELF_HEADERS 1
#define CONFIG_KCMP 1
#define CONFIG_XILINX_XADC 1
#define CONFIG_RTC_INTF_SYSFS 1
#define CONFIG_ARCH_INLINE_SPIN_LOCK_IRQSAVE 1
#define CONFIG_GCC_PLUGINS 1
#define CONFIG_BLK_DEV_INITRD 1
#define CONFIG_ARCH_ENABLE_MEMORY_HOTREMOVE 1
#define CONFIG_BT_ATH3K 1
#define CONFIG_PCPU_DEV_REFCNT 1
#define CONFIG_LEDS_TRIGGER_TIMER 1
#define CONFIG_DRM_VIRTIO_GPU 1
#define CONFIG_EDAC_SYNOPSYS 1
#define CONFIG_BT_INTEL 1
#define CONFIG_COMMON_CLK_VC7 1
#define CONFIG_FB_SYSMEM_HELPERS 1
#define CONFIG_PWM_CADENCE 1
#define CONFIG_SERIAL_DEV_BUS 1
#define CONFIG_USB_OTG 1
#define CONFIG_SPI_XILINX 1
#define CONFIG_NF_CT_PROTO_DCCP 1
#define CONFIG_ZLIB_INFLATE 1
#define CONFIG_NET_VENDOR_SYNOPSYS 1
#define CONFIG_DVB_DYNAMIC_MINORS 1
#define CONFIG_CFG80211_EXTRA_REGDB_KEYDIR ""
#define CONFIG_VIDEO_XILINX_SDIRXSS 1
#define CONFIG_HWMON 1
#define CONFIG_NET_VENDOR_DLINK 1
#define CONFIG_AUDITSYSCALL 1
#define CONFIG_BT_HCIUART_3WIRE 1
#define CONFIG_USB_PHY 1
#define CONFIG_ARCH_INLINE_WRITE_LOCK_BH 1
#define CONFIG_SENSORS_LM63 1
#define CONFIG_IP_PNP 1
#define CONFIG_USB_VIDEO_CLASS 1
#define CONFIG_RTC_INTF_PROC 1
#define CONFIG_PM_CLK 1
#define CONFIG_ARCH_INLINE_SPIN_TRYLOCK 1
#define CONFIG_CMA_SIZE_SEL_MBYTES 1
#define CONFIG_CC_IMPLICIT_FALLTHROUGH "-Wimplicit-fallthrough=5"
#define CONFIG_ARCH_HAS_UBSAN_SANITIZE_ALL 1
#define CONFIG_NF_CONNTRACK_OVS 1
#define CONFIG_DP83867_PHY 1
#define CONFIG_STACKTRACE_SUPPORT 1
#define CONFIG_SERIAL_8250_PCILIB 1
#define CONFIG_RESET_CONTROLLER 1
#define CONFIG_RCU_TRACE 1
#define CONFIG_ARCH_INLINE_WRITE_LOCK 1
#define CONFIG_ARM_CCI400_PMU 1
#define CONFIG_LOCKD 1
#define CONFIG_CRYPTO_LIB_ARC4_MODULE 1
#define CONFIG_CRYPTO_LIB_AES 1
#define CONFIG_WLAN_VENDOR_RALINK 1
#define CONFIG_CRYPTO_KPP2 1
#define CONFIG_NET_VENDOR_MICROCHIP 1
#define CONFIG_NEED_SG_DMA_FLAGS 1
#define CONFIG_JFFS2_FS 1
#define CONFIG_STE10XP 1
#define CONFIG_FUNCTION_ALIGNMENT 4
#define CONFIG_BT_RFCOMM_TTY 1
#define CONFIG_ARM64_ERRATUM_2658417 1
#define CONFIG_NET_UDP_TUNNEL_MODULE 1
#define CONFIG_RPCSEC_GSS_KRB5 1
#define CONFIG_CRYPTO_ECC 1
#define CONFIG_MTD_CFI_UTIL 1
#define CONFIG_NO_HZ_IDLE 1
#define CONFIG_NET_VENDOR_ADAPTEC 1
#define CONFIG_CFG80211_REQUIRE_SIGNED_REGDB 1
#define CONFIG_ARCH_BINFMT_ELF_EXTRA_PHDRS 1
#define CONFIG_ARM_SCMI_PROTOCOL 1
#define CONFIG_BSD_PROCESS_ACCT 1
#define CONFIG_SOCK_RX_QUEUE_MAPPING 1
#define CONFIG_MTD_CFI_INTELEXT 1
#define CONFIG_CRYPTO_DRBG_HMAC 1
#define CONFIG_DRM_BRIDGE 1
#define CONFIG_FB_DEVICE 1
#define CONFIG_USB_F_SERIAL_MODULE 1
#define CONFIG_NET_VENDOR_SILAN 1
#define CONFIG_SERIAL_AMBA_PL010_CONSOLE 1
#define CONFIG_SENSORS_PWM_FAN 1
#define CONFIG_ARCH_SUPPORTS_PER_VMA_LOCK 1
#define CONFIG_USB_STORAGE 1
#define CONFIG_NET_VENDOR_BROADCOM 1
#define CONFIG_GENERIC_CPU_AUTOPROBE 1
#define CONFIG_STANDALONE 1
#define CONFIG_ARM_GIC_V2M 1
#define CONFIG_EFI 1
#define CONFIG_RATIONAL 1
#define CONFIG_I2C_MUX 1
#define CONFIG_WLAN_VENDOR_INTEL 1
#define CONFIG_ARM_SCMI_POWER_CONTROL 1
#define CONFIG_ARM64_LSE_ATOMICS 1
#define CONFIG_SYSTEM_TRUSTED_KEYRING 1
#define CONFIG_WATCHDOG_CORE 1
#define CONFIG_GENERIC_EARLY_IOREMAP 1
#define CONFIG_ZYNQMP_PM_DOMAINS 1
#define CONFIG_SND_USB_AUDIO 1
#define CONFIG_NET_VENDOR_WANGXUN 1
#define CONFIG_ARM_CCI5xx_PMU 1
#define CONFIG_DRM_XLNX_BRIDGE_SCALER 1
#define CONFIG_AMPERE_ERRATUM_AC03_CPU_38 1
#define CONFIG_VMAP_STACK 1
#define CONFIG_BMG160_SPI 1
#define CONFIG_BLOCK 1
#define CONFIG_ARCH_STACKWALK 1
#define CONFIG_INIT_ENV_ARG_LIMIT 32
#define CONFIG_ARCH_INLINE_SPIN_UNLOCK 1
#define CONFIG_INLINE_READ_LOCK_BH 1
#define CONFIG_ROOT_NFS 1
#define CONFIG_AF_UNIX_OOB 1
#define CONFIG_USER_NS 1
#define CONFIG_ARCH_WANT_BATCHED_UNMAP_TLB_FLUSH 1
#define CONFIG_MAC80211_DEBUG_MENU 1
#define CONFIG_TMPFS_POSIX_ACL 1
#define CONFIG_STRICT_KERNEL_RWX 1
#define CONFIG_HAVE_ARCH_KCSAN 1
#define CONFIG_CFG80211_REG_CELLULAR_HINTS 1
#define CONFIG_NETLINK_DIAG 1
#define CONFIG_BUG 1
#define CONFIG_MAC80211_HAS_RC 1
#define CONFIG_ARCH_HAS_DEBUG_WX 1
#define CONFIG_PCIE_XILINX 1
#define CONFIG_OF_OVERLAY 1
#define CONFIG_ARM64_VA_BITS_48 1
#define CONFIG_XEN 1
#define CONFIG_ARCH_HAS_MEMBARRIER_SYNC_CORE 1
#define CONFIG_PM 1
#define CONFIG_ARCH_INLINE_SPIN_TRYLOCK_BH 1
#define CONFIG_PPS 1
#define CONFIG_MEMCG 1
#define CONFIG_SPI 1
#define CONFIG_RTC_SYSTOHC_DEVICE "rtc0"
#define CONFIG_ARM_SCMI_TRANSPORT_MAILBOX 1
#define CONFIG_OF_IRQ 1
#define CONFIG_LIBFDT 1
#define CONFIG_NET_FAILOVER 1
#define CONFIG_WLAN_VENDOR_PURELIFI 1
#define CONFIG_IO_URING 1
#define CONFIG_VT 1
#define CONFIG_USB_NET_NET1080 1
#define CONFIG_DMABUF_HEAPS 1
#define CONFIG_SECRETMEM 1
#define CONFIG_DTC 1
#define CONFIG_MACB 1
#define CONFIG_REGMAP_SPI 1
#define CONFIG_BT_BREDR 1
#define CONFIG_WATCHDOG_HANDLE_BOOT_ENABLED 1
#define CONFIG_SPLIT_PTLOCK_CPUS 4
#define CONFIG_SBITMAP 1
#define CONFIG_POWER_SUPPLY 1
#define CONFIG_SCSI_UFSHCD_PLATFORM 1
#define CONFIG_DAVICOM_PHY 1
#define CONFIG_CRYPTO_ZSTD 1
#define CONFIG_SND_DMAENGINE_PCM 1
#define CONFIG_WEXT_CORE 1
#define CONFIG_AS_HAS_ARMV8_4 1
#define CONFIG_ROCKCHIP_ERRATUM_3588001 1
#define CONFIG_CRYPTO_SKCIPHER2 1
#define CONFIG_DRM_XLNX_DPTX 1
#define CONFIG_NLS 1
#define CONFIG_ARCH_WANTS_NO_INSTR 1
#define CONFIG_VIDEO_XILINX_HLS 1
#define CONFIG_AS_IS_GNU 1
#define CONFIG_MEDIA_CAMERA_SUPPORT 1
#define CONFIG_ARM64_PAN 1
#define CONFIG_MICROSEMI_PHY 1
#define CONFIG_INET_UDP_DIAG 1
#define CONFIG_MEDIA_SDR_SUPPORT 1
#define CONFIG_USB_CONFIGFS_ACM 1
#define CONFIG_XFRM_MIGRATE 1
#define CONFIG_MTD_DATAFLASH 1
#define CONFIG_SYN_COOKIES 1
#define CONFIG_IRQ_WORK 1
#define CONFIG_PCI_MSI 1
#define CONFIG_ARCH_SUPPORTS_SHADOW_CALL_STACK 1
#define CONFIG_FB_SYS_COPYAREA 1
#define CONFIG_HAVE_ARCH_RANDOMIZE_KSTACK_OFFSET 1
#define CONFIG_XILINX_AXI_EMAC 1
#define CONFIG_SPI_BITBANG 1
#define CONFIG_SPARSEMEM_EXTREME 1
#define CONFIG_CC_HAS_BRANCH_PROT_PAC_RET_BTI 1
#define CONFIG_DRM_XLNX_BRIDGE 1
#define CONFIG_USB_COMMON 1
#define CONFIG_TASK_XACCT 1
#define CONFIG_DRM_DISPLAY_HDMI_HELPER 1
#define CONFIG_IP6_NF_IPTABLES 1
#define CONFIG_VIRTIO_ANCHOR 1
#define CONFIG_NL80211_TESTMODE 1
#define CONFIG_DEBUG_INFO_NONE 1
#define CONFIG_FIXED_PHY 1
#define CONFIG_CPU_FREQ_GOV_USERSPACE 1
#define CONFIG_LOG_CPU_MAX_BUF_SHIFT 12
#define CONFIG_HW_RANDOM_CN10K 1
#define CONFIG_NVMEM_ZYNQMP 1
#define CONFIG_SERIAL_UARTLITE 1
#define CONFIG_ARM64_LD_HAS_FIX_ERRATUM_843419 1
#define CONFIG_XEN_BLKDEV_BACKEND_MODULE 1
#define CONFIG_GENERIC_PINCONF 1
#define CONFIG_ARM_ARCH_TIMER 1
#define CONFIG_JFFS2_FS_XATTR 1
#define CONFIG_ARCH_HAS_NMI_SAFE_THIS_CPU_OPS 1
#define CONFIG_NFS_V4_2_SSC_HELPER 1
#define CONFIG_SG_POOL 1
#define CONFIG_DRM_KMS_HELPER 1
#define CONFIG_NET_VENDOR_PACKET_ENGINES 1
#define CONFIG_DMA_COHERENT_POOL 1
#define CONFIG_BLK_MQ_PCI 1
#define CONFIG_NLS_ISO8859_1 1
#define CONFIG_MMC_CQHCI 1
#define CONFIG_FS_IOMAP 1
#define CONFIG_VIDEO_XILINX_HDCP2X_RX 1
#define CONFIG_BT_HCIUART_LL 1
#define CONFIG_CAN_CALC_BITTIMING 1
#define CONFIG_MEMORY_HOTPLUG 1
#define CONFIG_COMPACT_UNEVICTABLE_DEFAULT 1
#define CONFIG_RD_ZSTD 1
#define CONFIG_RFKILL 1
#define CONFIG_NETDEVICES 1
#define CONFIG_NET_KEY 1
#define CONFIG_ARCH_HAS_KCOV 1
#define CONFIG_CGROUP_FREEZER 1
#define CONFIG_HAVE_ARCH_STACKLEAK 1
#define CONFIG_EVENTFD 1
#define CONFIG_FS_POSIX_ACL 1
#define CONFIG_IPV6_SIT 1
#define CONFIG_XFRM 1
#define CONFIG_LINEAR_RANGES 1
#define CONFIG_AS_HAS_LDAPR 1
#define CONFIG_SERIAL_8250_CONSOLE 1
#define CONFIG_USB_ANNOUNCE_NEW_DEVICES 1
#define CONFIG_ARCH_HAS_TEARDOWN_DMA_OPS 1
#define CONFIG_OVERLAY_FS 1
#define CONFIG_GPIO_XILINX 1
#define CONFIG_IP_NF_TARGET_MASQUERADE_MODULE 1
#define CONFIG_HAVE_EBPF_JIT 1
#define CONFIG_NF_CONNTRACK_BROADCAST 1
#define CONFIG_ECRYPT_FS 1
#define CONFIG_PROC_PAGE_MONITOR 1
#define CONFIG_USB_CONFIGFS_ECM 1
#define CONFIG_NETFILTER_XT_TARGET_MASQUERADE_MODULE 1
#define CONFIG_ARCH_INLINE_WRITE_UNLOCK 1
#define CONFIG_BPF 1
#define CONFIG_USB_VIDEO_CLASS_INPUT_EVDEV 1
#define CONFIG_CRYPTO_AES_ARM64_CE_CCM 1
#define CONFIG_INLINE_READ_LOCK_IRQSAVE 1
#define CONFIG_XILINX_SDFEC 1
#define CONFIG_RD_LZO 1
#define CONFIG_XILINX_FRMBUF 1
#define CONFIG_JFFS2_FS_SECURITY 1
#define CONFIG_HAVE_FUNCTION_GRAPH_RETVAL 1
#define CONFIG_ARM64_RAS_EXTN 1
#define CONFIG_CRYPTO_SHA512 1
#define CONFIG_BACKLIGHT_CLASS_DEVICE 1
#define CONFIG_CC_HAS_ASM_INLINE 1
#define CONFIG_MTD_OF_PARTS 1
#define CONFIG_OF_RESOLVE 1
#define CONFIG_CRYPTO_NULL 1
#define CONFIG_GPIO_CDEV_V1 1
#define CONFIG_NET_VENDOR_SEEQ 1
#define CONFIG_NF_DEFRAG_IPV4 1
#define CONFIG_BT_QCA 1
#define CONFIG_VIRTIO_CONSOLE 1
#define CONFIG_ARCH_HAS_RELR 1
#define CONFIG_ARCH_FORCE_MAX_ORDER 10
#define CONFIG_NETFILTER_ADVANCED 1
#define CONFIG_CRYPTO_DEFLATE 1
#define CONFIG_GENERIC_STRNLEN_USER 1
#define CONFIG_ARM64_TAGGED_ADDR_ABI 1
#define CONFIG_MTD_CFI 1
#define CONFIG_RPMSG_VIRTIO_MODULE 1
#define CONFIG_XILINX_HDCP_COMMON 1
#define CONFIG_MITIGATE_SPECTRE_BRANCH_HISTORY 1
#define CONFIG_JFFS2_FS_DEBUG 0
#define CONFIG_BT_HCIBTSDIO 1
#define CONFIG_WLAN_VENDOR_RSI 1
#define CONFIG_CRYPTO_JITTERENTROPY 1
#define CONFIG_ARCH_ENABLE_HUGEPAGE_MIGRATION 1
#define CONFIG_BT_HCIUART_SERDEV 1
#define CONFIG_VIDEO_XILINX_VPSS_CSC 1
#define CONFIG_CRYPTO_GCM 1
#define CONFIG_NETFILTER_NETLINK_LOG 1
#define CONFIG_HAVE_DYNAMIC_FTRACE 1
#define CONFIG_ARM64_SME 1
#define CONFIG_MAGIC_SYSRQ 1
#define CONFIG_QCOM_FALKOR_ERRATUM_1009 1
#define CONFIG_DMI 1
#define CONFIG_ARM64_ERRATUM_845719 1
#define CONFIG_CRYPTO_KPP 1
#define CONFIG_NET_VENDOR_RDC 1
#define CONFIG_VIDEO_XILINX_GAMMA 1
#define CONFIG_PGTABLE_LEVELS 4
#define CONFIG_CPUSETS 1
#define CONFIG_MAC80211_RC_DEFAULT_MINSTREL 1
#define CONFIG_SPARSE_IRQ 1
#define CONFIG_NET_SCH_MQPRIO_LIB 1
#define CONFIG_ARM64_ERRATUM_1508412 1
#define CONFIG_IP_NF_MANGLE 1
#define CONFIG_USB_MASS_STORAGE_MODULE 1
#define CONFIG_COMMON_CLK_PROXO 1
#define CONFIG_SECURITYFS 1
#define CONFIG_ARM64_ERRATUM_2067961 1
#define CONFIG_RCU_STALL_COMMON 1
#define CONFIG_BT_DEBUGFS 1
#define CONFIG_MEDIA_SUPPORT 1
#define CONFIG_DEBUG_BUGVERBOSE 1
#define CONFIG_EFI_GENERIC_STUB 1
#define CONFIG_IP_NF_FILTER_MODULE 1
#define CONFIG_EXT3_FS 1
#define CONFIG_ARM64_PTR_AUTH 1
#define CONFIG_MODULES_TREE_LOOKUP 1
#define CONFIG_FAT_FS 1
#define CONFIG_CRYPTO_SIG 1
#define CONFIG_ARM64_ERRATUM_832075 1
#define CONFIG_LSI_ET1011C_PHY 1
#define CONFIG_VIDEO_XILINX_VTC 1
#define CONFIG_BUILDTIME_TABLE_SORT 1
#define CONFIG_SERIAL_XILINX_PS_UART_CONSOLE 1
#define CONFIG_NVMEM 1
#define CONFIG_INET_TUNNEL 1
#define CONFIG_SENSORS_PMBUS 1
#define CONFIG_PINCONF 1
#define CONFIG_IIO_ST_LSM6DSX_I2C 1
#define CONFIG_DW_I3C_MASTER 1
#define CONFIG_GENERIC_CLOCKEVENTS 1
#define CONFIG_OID_REGISTRY 1
#define CONFIG_MEDIA_CEC_SUPPORT 1
#define CONFIG_MFD_CORE 1
#define CONFIG_SERIAL_AMBA_PL011 1
#define CONFIG_CAN_NETLINK 1
#define CONFIG_RFKILL_LEDS 1
#define CONFIG_BT_HCIBTUSB_BCM 1
#define CONFIG_CONSOLE_TRANSLATIONS 1
#define CONFIG_ARCH_SUPPORTS_ATOMIC_RMW 1
#define CONFIG_POWER_RESET_LTC2952 1
#define CONFIG_GENERIC_LIB_DEVMEM_IS_ALLOWED 1
#define CONFIG_RAID6_PQ 1
#define CONFIG_SWIOTLB_XEN 1
#define CONFIG_CRYPTO_AES_ARM64_CE 1
#define CONFIG_NF_NAT_SNMP_BASIC_MODULE 1
#define CONFIG_SERIAL_EARLYCON 1
#define CONFIG_NET_VENDOR_NI 1
#define CONFIG_CC_HAS_KASAN_SW_TAGS 1
#define CONFIG_CRYPTO_AKCIPHER 1
#define CONFIG_ETHTOOL_NETLINK 1
#define CONFIG_LEDS_TRIGGER_BACKLIGHT 1
#define CONFIG_CPU_FREQ 1
#define CONFIG_FPGA_MGR_VERSAL_FPGA 1
#define CONFIG_ARCH_SUPPORTS_KEXEC_FILE 1
#define CONFIG_CRYPTO_DEV_XILINX_RSA 1
#define CONFIG_DUMMY_CONSOLE 1
#define CONFIG_SERIAL_AMBA_PL011_CONSOLE 1
#define CONFIG_USB_PCI 1
#define CONFIG_RFKILL_GPIO 1
#define CONFIG_XLNX_HDCP1X_CIPHER 1
#define CONFIG_CFG80211_CERTIFICATION_ONUS 1
#define CONFIG_NF_REJECT_IPV4_MODULE 1
#define CONFIG_GENERIC_IOREMAP 1
#define CONFIG_COMMON_CLK_ZYNQMP 1
#define CONFIG_ARCH_MMAP_RND_BITS_MAX 33
#define CONFIG_HAVE_ARCH_TRANSPARENT_HUGEPAGE 1
#define CONFIG_TRACE_IRQFLAGS_SUPPORT 1
#define CONFIG_MTD_NAND_CORE 1
#define CONFIG_MFD_SYSCON 1
#define CONFIG_NFS_V3_ACL 1
#define CONFIG_CRYPTO_AES_ARM64_NEON_BLK 1
#define CONFIG_CRYPTO_CCM_MODULE 1
#define CONFIG_USB_NET_CDC_SUBSET 1
#define CONFIG_ARM_PMUV3 1
#define CONFIG_BT_RTL 1
#define CONFIG_QFMT_V2 1
#define CONFIG_ARM64_ERRATUM_824069 1
#define CONFIG_NETFILTER_XT_MATCH_CONNMARK_MODULE 1
#define CONFIG_BLK_CGROUP 1
#define CONFIG_PCIE_BUS_DEFAULT 1
#define CONFIG_UIO_PDRV_GENIRQ_MODULE 1
#define CONFIG_LEDS_TRIGGERS 1
#define CONFIG_CRYPTO_RNG 1
#define CONFIG_ARCH_MMAP_RND_COMPAT_BITS_MIN 11
#define CONFIG_CRYPTO_LIB_UTILS 1
#define CONFIG_SENSORS_IRPS5401 1
#define CONFIG_SND_USB 1
#define CONFIG_VIDEOBUF2_MEMOPS 1
#define CONFIG_RD_GZIP 1
#define CONFIG_HAVE_REGS_AND_STACK_ACCESS_API 1
#define CONFIG_BLK_PM 1
#define CONFIG_ARCH_INLINE_READ_LOCK 1
#define CONFIG_MDIO_BUS 1
#define CONFIG_TREE_RCU 1
#define CONFIG_PWM_SYSFS 1
#define CONFIG_ALLOW_DEV_COREDUMP 1
#define CONFIG_SWIOTLB 1
#define CONFIG_EXT4_FS_SECURITY 1
#define CONFIG_GRO_CELLS 1
#define CONFIG_SND_SOC_XILINX_SDI 1
#define CONFIG_HAVE_VIRT_CPU_ACCOUNTING_GEN 1
#define CONFIG_ARM64_BTI 1
#define CONFIG_CRYPTO_MD5 1
#define CONFIG_TRANSPARENT_HUGEPAGE 1
#define CONFIG_VSOCKETS_LOOPBACK 1
#define CONFIG_NET_SCH_SKBPRIO 1
#define CONFIG_ARM_SCMI_HAVE_TRANSPORT 1
#define CONFIG_ARCH_DEFAULT_KEXEC_IMAGE_VERIFY_SIG 1
#define CONFIG_NET_VENDOR_CORTINA 1
#define CONFIG_ELFCORE 1
#define CONFIG_HAVE_KVM 1
#define CONFIG_BINFMT_ELF 1
#define CONFIG_AUDIT_GENERIC 1
#define CONFIG_SCSI_PROC_FS 1
#define CONFIG_I2C_HID 1
#define CONFIG_IIO_TRIGGER 1
#define CONFIG_CICADA_PHY 1
#define CONFIG_HAVE_PERF_REGS 1
#define CONFIG_V4L2_ASYNC 1
#define CONFIG_MEDIA_ANALOG_TV_SUPPORT 1
#define CONFIG_DRM_XLNX_HDMITX 1
#define CONFIG_NET_VENDOR_ALTEON 1
#define CONFIG_REGULATOR_FIXED_VOLTAGE 1
#define CONFIG_XEN_PVCALLS_FRONTEND 1
#define CONFIG_NET_VENDOR_RENESAS 1
#define CONFIG_KEYS 1
#define CONFIG_XEN_EFI 1
#define CONFIG_NETFILTER_XT_MARK 1
#define CONFIG_NETFILTER_XTABLES 1
#define CONFIG_DRM_PANEL_ORIENTATION_QUIRKS 1
#define CONFIG_HAVE_ARCH_AUDITSYSCALL 1
#define CONFIG_ARCH_INLINE_WRITE_UNLOCK_IRQ 1
#define CONFIG_LEGACY_TIOCSTI 1
#define CONFIG_INLINE_SPIN_UNLOCK_IRQRESTORE 1
#define CONFIG_ARM64_PA_BITS_48 1
#define CONFIG_CRYPTO_USER_API_HASH 1
#define CONFIG_INLINE_WRITE_LOCK_IRQ 1
#define CONFIG_PM_SLEEP_SMP 1
#define CONFIG_CRYPTO_HW 1
#define CONFIG_ARM64_ERRATUM_3117295 1
#define CONFIG_DRM_XLNX 1
#define CONFIG_HAVE_DYNAMIC_FTRACE_WITH_ARGS 1
#define CONFIG_MAGIC_SYSRQ_DEFAULT_ENABLE 0x1
#define CONFIG_HARDIRQS_SW_RESEND 1
#define CONFIG_JFFS2_FS_WRITEBUFFER 1
#define CONFIG_SPI_MASTER 1
#define CONFIG_ARCH_HAS_KEEPINITRD 1
#define CONFIG_VT_HW_CONSOLE_BINDING 1
#define CONFIG_MPLS 1
#define CONFIG_INLINE_SPIN_LOCK_IRQSAVE 1
#define CONFIG_SRAM 1
#define CONFIG_BT_HCIBCM203X 1
#define CONFIG_UNMAP_KERNEL_AT_EL0 1
#define CONFIG_I2C_MUX_PCA9541 1
#define CONFIG_CRYPTO_SKCIPHER 1
#define CONFIG_SERIAL_OF_PLATFORM 1
#define CONFIG_MTD_RAW_NAND 1
#define CONFIG_MAC80211_LEDS 1
#define CONFIG_CONSOLE_LOGLEVEL_QUIET 4
#define CONFIG_CRC16 1
#define CONFIG_USB_NET_AX8817X 1
#define CONFIG_GENERIC_CALIBRATE_DELAY 1
#define CONFIG_NET_CLS 1
#define CONFIG_TMPFS 1
#define CONFIG_NET_VENDOR_NETERION 1
#define CONFIG_CADENCE_WATCHDOG 1
#define CONFIG_RANDSTRUCT_NONE 1
#define CONFIG_FPGA_REGION 1
#define CONFIG_FUTEX 1
#define CONFIG_IP_PNP_DHCP 1
#define CONFIG_VIRTIO_PCI 1
#define CONFIG_UNIX_SCM 1
#define CONFIG_CONSOLE_LOGLEVEL_DEFAULT 7
#define CONFIG_REGMAP_I2C 1
#define CONFIG_GENERIC_SCHED_CLOCK 1
#define CONFIG_ARCH_HAS_FAST_MULTIPLIER 1
#define CONFIG_ZYNQMP_FIRMWARE_DEBUG 1
#define CONFIG_NET_VENDOR_REALTEK 1
#define CONFIG_ARCH_HAVE_NMI_SAFE_CMPXCHG 1
#define CONFIG_XILINX_AIE 1
#define CONFIG_DVB_CORE 1
#define CONFIG_CRYPTO_USER_API 1
#define CONFIG_RTC_HCTOSYS 1
#define CONFIG_HAVE_ARCH_BITREVERSE 1
#define CONFIG_SERIAL_CORE_CONSOLE 1
#define CONFIG_HUGETLB_PAGE 1
#define CONFIG_HW_RANDOM_TPM 1
#define CONFIG_HAVE_ARCH_KASAN_HW_TAGS 1
#define CONFIG_VIDEO_XILINX_REMAPPER 1
#define CONFIG_NET_VENDOR_EMULEX 1
#define CONFIG_REGMAP_IRQ 1
#define CONFIG_ARCH_INLINE_SPIN_UNLOCK_IRQ 1
#define CONFIG_USB_HID 1
#define CONFIG_LD_ORPHAN_WARN_LEVEL "warn"
#define CONFIG_FPGA 1
#define CONFIG_RODATA_FULL_DEFAULT_ENABLED 1
#define CONFIG_UBIFS_FS 1
#define CONFIG_VSOCKETS_DIAG 1
#define CONFIG_SLUB_DEBUG 1
#define CONFIG_UCS2_STRING 1
#define CONFIG_USB_F_RNDIS 1
#define CONFIG_DMADEVICES 1
#define CONFIG_XENFS 1
#define CONFIG_PAHOLE_VERSION 0
#define CONFIG_PINCTRL 1
#define CONFIG_ARCH_SUPPORTS_CFI_CLANG 1
#define CONFIG_IPV6_NDISC_NODETYPE 1
#define CONFIG_PCI_LABEL 1
#define CONFIG_ARCH_WANT_DEFAULT_BPF_JIT 1
#define CONFIG_CGROUP_SCHED 1
#define CONFIG_QUEUED_RWLOCKS 1
#define CONFIG_SYSVIPC 1
#define CONFIG_RAID6_PQ_BENCHMARK 1
#define CONFIG_ARCH_HAS_GIGANTIC_PAGE 1
#define CONFIG_USB_CONFIGFS_ECM_SUBSET 1
#define CONFIG_HAVE_DEBUG_KMEMLEAK 1
#define CONFIG_ARM_GIC_V3_ITS 1
#define CONFIG_KEYBOARD_GPIO 1
#define CONFIG_NF_CONNTRACK_FTP 1
#define CONFIG_PAGE_SIZE_LESS_THAN_64KB 1
#define CONFIG_FPGA_BRIDGE 1
#define CONFIG_MODULES 1
#define CONFIG_RPMSG_MODULE 1
#define CONFIG_VIDEO_IMX219 1
#define CONFIG_USB_GADGET 1
#define CONFIG_CONTEXT_TRACKING 1
#define CONFIG_CRYPTO_SHA512_ARM64_CE 1
#define CONFIG_MQ_IOSCHED_DEADLINE 1
#define CONFIG_GENERIC_IRQ_IPI 1
#define CONFIG_IOMMU_IOVA 1
#define CONFIG_VIDEO_XILINX_M2M 1
#define CONFIG_DUMMY_CONSOLE_COLUMNS 80
#define CONFIG_USB_ETH_RNDIS 1
#define CONFIG_XXHASH 1
#define CONFIG_AXIENET_HAS_TADMA 1
#define CONFIG_SOUND 1
#define CONFIG_JOLIET 1
#define CONFIG_WLCORE_SPI_MODULE 1
#define CONFIG_ARCH_SUPPORTS_MEMORY_FAILURE 1
#define CONFIG_VIDEO_XILINX_VPSS_SCALER 1
#define CONFIG_ARM64_ERRATUM_2051678 1
#define CONFIG_ARCH_HIBERNATION_POSSIBLE 1
#define CONFIG_ARCH_USE_SYM_ANNOTATIONS 1
#define CONFIG_PROC_CHILDREN 1
#define CONFIG_UNIX 1
#define CONFIG_USB_NET_DRIVERS 1
#define CONFIG_LD_IS_BFD 1
#define CONFIG_NO_HZ_COMMON 1
#define CONFIG_DRM_MIPI_DSI 1
#define CONFIG_XEN_DEV_EVTCHN 1
#define CONFIG_HAVE_CLK 1
#define CONFIG_CRYPTO_HASH2 1
#define CONFIG_COMMON_CLK_XLNX_CLKWZRD 1
#define CONFIG_NET_VENDOR_VERTEXCOM 1
#define CONFIG_BT_HCIBTUSB_POLL_SYNC 1
#define CONFIG_DEFAULT_HOSTNAME "(none)"
#define CONFIG_USB_GADGET_STORAGE_NUM_BUFFERS 2
#define CONFIG_CC_HAS_NO_PROFILE_FN_ATTR 1
#define CONFIG_ARCH_INLINE_READ_UNLOCK 1
#define CONFIG_NFS_FS 1
#define CONFIG_CRASH_DUMP 1
#define CONFIG_MEMBARRIER 1
#define CONFIG_XPS 1
#define CONFIG_SGL_ALLOC 1
#define CONFIG_XILINX_WINDOW_WATCHDOG 1
#define CONFIG_LZ4_DECOMPRESS 1
#define CONFIG_DP83848_PHY 1
#define CONFIG_FONT_SUPPORT 1
#define CONFIG_ADVISE_SYSCALLS 1
#define CONFIG_CRYPTO_ALGAPI 1
#define CONFIG_GENERIC_IRQ_SHOW_LEVEL 1
#define CONFIG_ARM64_ERRATUM_1463225 1
#define CONFIG_HOTPLUG_CORE_SYNC 1
#define CONFIG_XILINX_AMS 1
#define CONFIG_NET_VENDOR_WIZNET 1
#define CONFIG_BRIDGE 1
#define CONFIG_MEDIA_TUNER 1
#define CONFIG_EEPROM_AT25 1
#define CONFIG_SCHED_MM_CID 1
#define CONFIG_RD_BZIP2 1
#define CONFIG_ARM64_HW_AFDBM 1
#define CONFIG_WANT_DEV_COREDUMP 1
#define CONFIG_NETFILTER_XT_TARGET_CHECKSUM_MODULE 1
#define CONFIG_HAVE_ARM_SMCCC_DISCOVERY 1
#define CONFIG_SKB_EXTENSIONS 1
#define CONFIG_PM_OPP 1
#define CONFIG_GPIO_CDEV 1
#define CONFIG_CRYPTO_SHA2_ARM64_CE 1
#define CONFIG_CC_VERSION_TEXT "gcc (GCC) 13.3.0"
#define CONFIG_KEYBOARD_ATKBD 1
#define CONFIG_NET_IP_TUNNEL 1
#define CONFIG_MTD_CFI_I1 1
#define CONFIG_NF_NAT_MODULE 1
#define CONFIG_UBIFS_FS_ZLIB 1
#define CONFIG_BLOCK_LEGACY_AUTOLOAD 1
#define CONFIG_NET_VENDOR_OKI 1
#define CONFIG_WLAN_VENDOR_INTERSIL 1
#define CONFIG_NFS_COMMON 1
#define CONFIG_REGULATOR 1
#define CONFIG_FAIR_GROUP_SCHED 1
#define CONFIG_CRYPTO_HASH 1
#define CONFIG_EFI_PARTITION 1
#define CONFIG_TRACE_CLOCK 1
#define CONFIG_LOG_BUF_SHIFT 16
#define CONFIG_WLAN_VENDOR_ATH 1
#define CONFIG_USB_RTL8153_ECM 1
#define CONFIG_EXTRA_FIRMWARE ""
#define CONFIG_TCG_TPM 1
#define CONFIG_NET_VENDOR_8390 1
#define CONFIG_XILINX_TSN_CB 1
#define CONFIG_PROC_EVENTS 1
#define CONFIG_HAVE_KCSAN_COMPILER 1
#define CONFIG_VFAT_FS 1
#define CONFIG_ARCH_SUPPORTS_ACPI 1
#define CONFIG_ARCH_INLINE_WRITE_UNLOCK_BH 1
#define CONFIG_PID_NS 1
#define CONFIG_UIO_XILINX_AI_ENGINE_MODULE 1
#define CONFIG_MEDIA_PLATFORM_DRIVERS 1
#define CONFIG_CRC32_SLICEBY8 1
#define CONFIG_ARM64_PTR_AUTH_KERNEL 1
#define CONFIG_USB_LIBCOMPOSITE 1
#define CONFIG_HVC_XEN 1
#define CONFIG_CRYPTO_SM3 1
#define CONFIG_XILINX_VCU_MODULE 1
#define CONFIG_EFI_PARAMS_FROM_FDT 1
#define CONFIG_XEN_SCRUB_PAGES_DEFAULT 1
#define CONFIG_CPU_RMAP 1
#define CONFIG_SND_HWDEP 1
#define CONFIG_BLK_DEV_LOOP 1
#define CONFIG_VIRTIO_PCI_LEGACY 1
#define CONFIG_SPI_MEM 1
#define CONFIG_ARM64_ERRATUM_843419 1
#define CONFIG_COMMON_CLK_SI5341 1
#define CONFIG_INPUT_MISC 1
#define CONFIG_ARCH_INLINE_WRITE_LOCK_IRQ 1
#define CONFIG_INPUT_VIVALDIFMAP 1
#define CONFIG_MULTIUSER 1
#define CONFIG_DMA_OF 1
#define CONFIG_SUSPEND 1
#define CONFIG_GENERIC_VDSO_TIME_NS 1
#define CONFIG_CROSS_MEMORY_ATTACH 1
#define CONFIG_MTD_NAND_ECC 1
#define CONFIG_CRYPTO_CBC 1
#define CONFIG_MEDIA_CONTROLLER 1
#define CONFIG_EFI_ARMSTUB_DTB_LOADER 1
#define CONFIG_SERIAL_8250_RUNTIME_UARTS 4
#define CONFIG_CRYPTO_CHACHA20_NEON 1
#define CONFIG_CLANG_VERSION 0
#define CONFIG_CDNS_I3C_MASTER 1
#define CONFIG_FS_MBCACHE 1
#define CONFIG_RTC_CLASS 1
#define CONFIG_CRC7_MODULE 1
#define CONFIG_CRYPTO_RNG_DEFAULT 1
#define CONFIG_TMPFS_XATTR 1
#define CONFIG_EXT4_USE_FOR_EXT2 1
#define CONFIG_ARM64_ERRATUM_1742098 1
#define CONFIG_INLINE_WRITE_UNLOCK_BH 1
#define CONFIG_BCM_NET_PHYLIB 1
#define CONFIG_ARM_AMBA 1
#define CONFIG_CPU_PM 1
#define CONFIG_V4L2_FWNODE 1
#define CONFIG_QCOM_FALKOR_ERRATUM_1003 1
#define CONFIG_CFG80211_USE_KERNEL_REGDB_KEYS 1
#define CONFIG_TIMER_OF 1
#define CONFIG_ARCH_HAS_DMA_PREP_COHERENT 1
#define CONFIG_HAVE_FUNCTION_TRACER 1
#define CONFIG_GENERIC_PHY 1
#define CONFIG_CPU_ISOLATION 1
#define CONFIG_NF_NAT_TFTP_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_MULTIPORT 1
#define CONFIG_MTD_SPI_NOR 1
#define CONFIG_DRM_DISPLAY_DP_HELPER 1
#define CONFIG_NFSD_V4 1
#define CONFIG_PMBUS 1
#define CONFIG_ARM64_ERRATUM_2645198 1
#define CONFIG_CRYPTO_MANAGER2 1
#define CONFIG_SERIAL_8250_DEPRECATED_OPTIONS 1
#define CONFIG_USB_GADGET_VBUS_DRAW 2
#define CONFIG_ARCH_HAS_PTE_SPECIAL 1
#define CONFIG_NET_VENDOR_MYRI 1
#define CONFIG_ARM64_AS_HAS_MTE 1
#define CONFIG_NF_NAT_MASQUERADE 1
#define CONFIG_PM_GENERIC_DOMAINS_OF 1
#define CONFIG_CLZ_TAB 1
#define CONFIG_ARCH_SUPPORTS_KEXEC_IMAGE_VERIFY_SIG 1
#define CONFIG_GENERIC_PCI_IOMAP 1
#define CONFIG_NETFILTER_XT_TARGET_LOG 1
#define CONFIG_SLUB 1
#define CONFIG_CONFIGFS_FS 1
#define CONFIG_MTD_UBI 1
#define CONFIG_IRQCHIP_XILINX_INTC_MODULE_SUPPORT_EXPERIMENTAL 1
#define CONFIG_ARCH_SUPPORTS_LTO_CLANG_THIN 1
#define CONFIG_PM_SLEEP 1
#define CONFIG_I2C 1
#define CONFIG_JFFS2_ZLIB 1
#define CONFIG_ARM64_ERRATUM_2457168 1
#define CONFIG_ARM64_WORKAROUND_SPECULATIVE_AT 1
#define CONFIG_MMU_GATHER_TABLE_FREE 1
#define CONFIG_BINFMT_SCRIPT 1
#define CONFIG_EFI_STUB 1
#define CONFIG_BFQ_GROUP_IOSCHED 1
#define CONFIG_ARM64_WORKAROUND_TSB_FLUSH_FAILURE 1
#define CONFIG_FRAME_POINTER 1
#define CONFIG_BT_HIDP 1
#define CONFIG_ARCH_INLINE_SPIN_LOCK 1
#define CONFIG_TICK_CPU_ACCOUNTING 1
#define CONFIG_CRYPTO_ECDSA 1
#define CONFIG_VM_EVENT_COUNTERS 1
#define CONFIG_VIDEO_XILINX_ISP 1
#define CONFIG_CRYPTO_ECB 1
#define CONFIG_WLAN_VENDOR_BROADCOM 1
#define CONFIG_BT_HCIUART_ATH3K 1
#define CONFIG_I2C_SLAVE 1
#define CONFIG_DEBUG_FS 1
#define CONFIG_NET_VENDOR_AMD 1
#define CONFIG_NET_PKTGEN 1
#define CONFIG_BASE_FULL 1
#define CONFIG_ZLIB_DEFLATE 1
#define CONFIG_SUNRPC 1
#define CONFIG_ARM_CCI_PMU 1
#define CONFIG_RPMSG_NS_MODULE 1
#define CONFIG_ARCH_USES_HIGH_VMA_FLAGS 1
#define CONFIG_CACHESTAT_SYSCALL 1
#define CONFIG_RSEQ 1
#define CONFIG_IIO_BUFFER 1
#define CONFIG_XEN_BACKEND 1
#define CONFIG_FW_LOADER 1
#define CONFIG_KALLSYMS 1
#define CONFIG_COMMON_CLK 1
#define CONFIG_BMG160_I2C 1
#define CONFIG_STACKPROTECTOR_STRONG 1
#define CONFIG_PCI 1
#define CONFIG_RTC_HCTOSYS_DEVICE "rtc0"
#define CONFIG_HAVE_ARCH_COMPILER_H 1
#define CONFIG_NET_VENDOR_FUNGIBLE 1
#define CONFIG_CONTIG_ALLOC 1
#define CONFIG_PWM 1
#define CONFIG_NET_VENDOR_ASIX 1
#define CONFIG_DECOMPRESS_XZ 1
#define CONFIG_SERIAL_DEV_CTRL_TTYPORT 1
#define CONFIG_PCI_QUIRKS 1
#define CONFIG_BT_BCM 1
#define CONFIG_MII 1
#define CONFIG_SIGNALFD 1
#define CONFIG_NET_CORE 1
#define CONFIG_VIDEO_XILINX_DPRXSS 1
#define CONFIG_KEXEC_CORE 1
#define CONFIG_EXT4_FS 1
#define CONFIG_MEMORY_BALLOON 1
#define CONFIG_CRYPTO_DEV_ZYNQMP_AES 1
#define CONFIG_HAVE_HW_BREAKPOINT 1
#define CONFIG_SND_JACK_INPUT_DEV 1
#define CONFIG_CRYPTO_SHA1 1
#define CONFIG_VERSAL_SYSMON_CORE 1
#define CONFIG_HAVE_SAMPLE_FTRACE_DIRECT 1
#define CONFIG_USB_BELKIN 1
#define CONFIG_SATA_PMP 1
#define CONFIG_XZ_DEC 1
#define CONFIG_NET_VENDOR_TI 1
#define CONFIG_LOCKD_V4 1
#define CONFIG_NET_VENDOR_ALACRITECH 1
#define CONFIG_BRIDGE_EBT_MARK_T_MODULE 1
#define CONFIG_WATCHDOG 1
#define CONFIG_SENSORS_IR38064 1
#define CONFIG_CC_HAVE_SHADOW_CALL_STACK 1
#define CONFIG_HAS_IOMEM 1
#define CONFIG_SND_RAWMIDI 1
#define CONFIG_NF_LOG_IPV6 1
#define CONFIG_CRYPTO_RSA 1
#define CONFIG_DMA_DIRECT_REMAP 1
#define CONFIG_BT_HCIUART_INTEL 1
#define CONFIG_GENERIC_IRQ_PROBE 1
#define CONFIG_CRYPTO_SIG2 1
#define CONFIG_ARCH_INLINE_READ_UNLOCK_IRQ 1
#define CONFIG_PWRSEQ_EMMC 1
#define CONFIG_HAVE_MOVE_PUD 1
#define CONFIG_VIDEOMODE_HELPERS 1
#define CONFIG_CRYPTO_ACOMP2 1
#define CONFIG_ARM64_ERRATUM_2054223 1
#define CONFIG_MTD_NAND_ECC_SW_BCH 1
#define CONFIG_ARCH_INLINE_SPIN_UNLOCK_BH 1
#define CONFIG_ARCH_HAS_SETUP_DMA_OPS 1
#define CONFIG_HVC_IRQ 1
#define CONFIG_HAVE_ARCH_KASAN_VMALLOC 1
#define CONFIG_ZYNQMP_R5_REMOTEPROC_MODULE 1
#define CONFIG_MTD_MAP_BANK_WIDTH_1 1
#define CONFIG_XILINX_INTC 1
#define CONFIG_SCHED_HRTICK 1
#define CONFIG_EPOLL 1
#define CONFIG_CRYPTO_LZO 1
#define CONFIG_SND_PCM 1
#define CONFIG_FAILOVER 1
#define CONFIG_ICPLUS_PHY 1
#define CONFIG_ARM_CCI400_COMMON 1
#define CONFIG_CGROUP_HUGETLB 1
#define CONFIG_USB_U_ETHER 1
#define CONFIG_BT_BNEP_MC_FILTER 1
#define CONFIG_SND_SOC_XILINX_DP 1
#define CONFIG_SERIAL_XILINX_PS_UART 1
#define CONFIG_GENERIC_PTDUMP 1
#define CONFIG_AS_HAS_ARMV8_5 1
#define CONFIG_NET 1
#define CONFIG_MTD_SPI_NOR_SWP_DISABLE_ON_VOLATILE 1
#define CONFIG_INPUT_EVDEV 1
#define CONFIG_SND_JACK 1
#define CONFIG_CC_HAS_AUTO_VAR_INIT_PATTERN 1
#define CONFIG_VIDEO_XILINX_CSI2RXSS 1
#define CONFIG_VIRTIO_DMA_SHARED_BUFFER 1
#define CONFIG_CRYPTO_LIB_BLAKE2S_GENERIC 1
#define CONFIG_NETFILTER_XT_MATCH_CONNTRACK_MODULE 1
#define CONFIG_ARM64_ERRATUM_2441007 1
#define CONFIG_PWRSEQ_SIMPLE 1
#define CONFIG_PINMUX 1
#define CONFIG_MTD_GEN_PROBE 1
#define CONFIG_SCSI_UFS_BSG 1
#define CONFIG_QUOTA_TREE 1
#define CONFIG_IRQ_DOMAIN_HIERARCHY 1
#define CONFIG_HVC_XEN_FRONTEND 1
#define CONFIG_ATA_FORCE 1
#define CONFIG_HW_RANDOM_ARM_SMCCC_TRNG 1
#define CONFIG_MPILIB 1
#define CONFIG_USB_NET_CDCETHER 1
#define CONFIG_PACKET 1
#define CONFIG_XFRM_ALGO 1
#define CONFIG_BLK_ICQ 1
#define CONFIG_HAVE_CLK_PREPARE 1
#define CONFIG_DRM_XLNX_BRIDGE_VTC 1
#define CONFIG_CRYPTO_AKCIPHER2 1
#define CONFIG_ASYMMETRIC_PUBLIC_KEY_SUBTYPE 1
#define CONFIG_FB_IOMEM_FOPS 1
#define CONFIG_SND_CTL_FAST_LOOKUP 1
#define CONFIG_ARCH_WANT_PMD_MKWRITE 1
#define CONFIG_CRYPTO_SM3_ARM64_CE 1
#define CONFIG_DRM_XLNX_PL_DISP 1
#define CONFIG_ARM64_WORKAROUND_SPECULATIVE_UNPRIV_LOAD 1
#define CONFIG_DUMMY_CONSOLE_ROWS 25
#define CONFIG_USB_XHCI_PLATFORM 1
#define CONFIG_NF_CONNTRACK_TFTP 1
#define CONFIG_NFS_V3 1
#define CONFIG_XEN_XENBUS_FRONTEND 1
#define CONFIG_INET 1
#define CONFIG_DRM_XLNX_MIXER 1
#define CONFIG_ARM64_MTE 1
#define CONFIG_IP_PNP_BOOTP 1
#define CONFIG_VIRTIO_NET 1
#define CONFIG_NETFILTER_XT_MATCH_ADDRTYPE_MODULE 1
#define CONFIG_NET_VENDOR_HUAWEI 1
#define CONFIG_PREVENT_FIRMWARE_BUILD 1
#define CONFIG_FREEZER 1
#define CONFIG_USB_F_SUBSET 1
#define CONFIG_DRM_FBDEV_LEAK_PHYS_SMEM 1
#define CONFIG_BT 1
#define CONFIG_BT_HCIVHCI 1
#define CONFIG_ARM64_4K_PAGES 1
#define CONFIG_PCI_DOMAINS 1
#define CONFIG_NET_VENDOR_CHELSIO 1
#define CONFIG_EFIVAR_FS_MODULE 1
#define CONFIG_HAVE_ARCH_VMAP_STACK 1
#define CONFIG_NFS_V4_1_IMPLEMENTATION_ID_DOMAIN "kernel.org"
#define CONFIG_BT_LE_L2CAP_ECRED 1
#define CONFIG_USB_F_ACM 1
#define CONFIG_ARM64_ERRATUM_1319367 1
#define CONFIG_INLINE_SPIN_TRYLOCK_BH 1
#define CONFIG_RTC_LIB 1
#define CONFIG_ARM64_ERRATUM_826319 1
#define CONFIG_HAVE_KPROBES 1
#define CONFIG_XILINX_ZYNQMP_DMA 1
#define CONFIG_CRYPTO_AES 1
#define CONFIG_HAVE_GENERIC_VDSO 1
#define CONFIG_INLINE_WRITE_LOCK_IRQSAVE 1
#define CONFIG_GPIOLIB 1
#define CONFIG_ARCH_WANT_DEFAULT_TOPDOWN_MMAP_LAYOUT 1
#define CONFIG_FUTEX_PI 1
#define CONFIG_CDX_CONTROLLER_MODULE 1
#define CONFIG_GENERIC_CPU_VULNERABILITIES 1
#define CONFIG_BMC150_MAGN 1
#define CONFIG_AUTOFS_FS 1
#define CONFIG_ISO9660_FS 1
#define CONFIG_NETFILTER_XT_NAT_MODULE 1
#define CONFIG_BT_HCIUART_H4 1
#define CONFIG_DMA_NONCOHERENT_MMAP 1
#define CONFIG_SND_PCM_ELD 1
#define CONFIG_XEN_WDT_MODULE 1
#define CONFIG_UIO 1
#define CONFIG_UIO_DMEM_GENIRQ_MODULE 1
#define CONFIG_DRM_XLNX_SDI 1
#define CONFIG_ARM_ARCH_TIMER_OOL_WORKAROUND 1
#define CONFIG_NET_VENDOR_AQUANTIA 1
#define CONFIG_SCSI_VIRTIO 1
#define CONFIG_NF_CONNTRACK_MARK 1
#define CONFIG_XILINX_AFI_FPGA 1
#define CONFIG_HVC_DRIVER 1
#define CONFIG_NETFILTER 1
#define CONFIG_HAVE_ARCH_KASAN 1
#define CONFIG_BME680 1
#define CONFIG_NET_VENDOR_SMSC 1
#define CONFIG_CAVIUM_ERRATUM_23154 1
#define CONFIG_GENERIC_ARCH_TOPOLOGY 1
#define CONFIG_SERIO_SERPORT 1
#define CONFIG_CLONE_BACKWARDS 1
#define CONFIG_LEDS_TRIGGER_ONESHOT 1
#define CONFIG_HAVE_NMI 1
#define CONFIG_BT_BNEP 1
#define CONFIG_BLK_DEV_RAM_COUNT 16
#define CONFIG_RD_XZ 1
#define CONFIG_HAVE_PREEMPT_DYNAMIC_KEY 1
#define CONFIG_CRYPTO_ECDH 1
#define CONFIG_USB_ONBOARD_DEV 1
#define CONFIG_ATA_VERBOSE_ERROR 1
#define CONFIG_XEN_BLKDEV_FRONTEND 1
#define CONFIG_NF_CONNTRACK_SNMP 1
#define CONFIG_NET_FLOW_LIMIT 1
#define CONFIG_LOCKDEP_SUPPORT 1
#define CONFIG_DRM_XLNX_DSI 1
#define CONFIG_ARCH_WANT_COMPAT_IPC_PARSE_VERSION 1
#define CONFIG_NO_HZ 1
#define CONFIG_ARCH_WANT_HUGE_PMD_SHARE 1
#define CONFIG_POSIX_MQUEUE 1
#define CONFIG_CC_HAS_WORKING_NOSANITIZE_ADDRESS 1
#define CONFIG_NETFILTER_INGRESS 1
#define CONFIG_CRYPTO_LIB_GF128MUL 1
#define CONFIG_ARCH_INLINE_WRITE_UNLOCK_IRQRESTORE 1
#define CONFIG_VIDEO_XILINX_HDMI21RXSS 1
#define CONFIG_CAVIUM_ERRATUM_27456 1
#define CONFIG_USB_DWC3_OF_SIMPLE 1
#define CONFIG_ARM_SMMU_V3 1
#define CONFIG_XEN_PRIVCMD 1
#define CONFIG_GENERIC_STRNCPY_FROM_USER 1
#define CONFIG_MEDIA_PLATFORM_SUPPORT 1
#define CONFIG_MTD_BLKDEVS 1
#define CONFIG_HAVE_RSEQ 1
#define CONFIG_NET_SCH_MQPRIO 1
#define CONFIG_ARM64_ERRATUM_858921 1
#define CONFIG_OF_KOBJ 1
#define CONFIG_CONTEXT_TRACKING_IDLE 1
#define CONFIG_CRASH_CORE 1
#define CONFIG_NET_VENDOR_DEC 1
#define CONFIG_XILINX_TSN 1
#define CONFIG_NET_NSH_MODULE 1
#define CONFIG_ILLEGAL_POINTER_VALUE 0xdead000000000000
#define CONFIG_GENERIC_GETTIMEOFDAY 1
#define CONFIG_JFFS2_CMODE_PRIORITY 1
#define CONFIG_OF_CONFIGFS 1
#define CONFIG_ARCH_USE_MEMTEST 1
#define CONFIG_TASKSTATS 1
#define CONFIG_OF_FPGA_REGION 1
#define CONFIG_MTD_NAND_ECC_SW_HAMMING 1
#define CONFIG_NET_VENDOR_PENSANDO 1
#define CONFIG_IP6_NF_FILTER 1
#define CONFIG_SYSTEM_DATA_VERIFICATION 1
#define CONFIG_EFI_ESRT 1
#define CONFIG_NEED_DMA_MAP_STATE 1
#define CONFIG_IIO 1
#define CONFIG_SND_HDA_PREALLOC_SIZE 64
#define CONFIG_CRYPTO_DEV_XILINX_ECDSA 1
#define CONFIG_SERIO_LIBPS2 1
#define CONFIG_INLINE_WRITE_LOCK 1
#define CONFIG_HAVE_ARCH_KASAN_SW_TAGS 1
#define CONFIG_FONT_8x8 1
#define CONFIG_XILINX_FCLK 1
#define CONFIG_XEN_PCIDEV_STUB_MODULE 1
#define CONFIG_NET_VENDOR_ATHEROS 1
#define CONFIG_RELOCATABLE 1
#define CONFIG_QUEUED_SPINLOCKS 1
#define CONFIG_XOR_BLOCKS 1
#define CONFIG_TIME_NS 1
#define CONFIG_DMABUF_HEAPS_CMA 1
#define CONFIG_CRYPTO_SHA3_ARM64 1
#define CONFIG_NET_VENDOR_SUN 1
#define CONFIG_DMIID 1
#define CONFIG_PANIC_TIMEOUT 0
#define CONFIG_NF_NAT_OVS 1
#define CONFIG_PM_GENERIC_DOMAINS_SLEEP 1
#define CONFIG_HAVE_ARCH_SECCOMP 1
#define CONFIG_STACKDEPOT 1
#define CONFIG_CFG80211_DEFAULT_PS 1
#define CONFIG_SERIAL_AMBA_PL010 1
#define CONFIG_RTC_DRV_ZYNQMP 1
#define CONFIG_NET_VENDOR_XILINX 1
#define CONFIG_DECOMPRESS_LZ4 1
#define CONFIG_ARM_SMCCC_SOC_ID 1
#define CONFIG_PREEMPT_NONE 1
#define CONFIG_XEN_FBDEV_FRONTEND 1
#define CONFIG_VIDEO_V4L2_I2C 1
#define CONFIG_SMP 1
#define CONFIG_NET_VENDOR_CADENCE 1
#define CONFIG_NET_VENDOR_MICROSOFT 1
#define CONFIG_TTY 1
#define CONFIG_INLINE_SPIN_LOCK 1
#define CONFIG_NET_VENDOR_I825XX 1
#define CONFIG_NETFILTER_XT_MATCH_MAC 1
#define CONFIG_IOMMU_DMA 1
#define CONFIG_RCU_EXP_CPU_STALL_TIMEOUT 0
#define CONFIG_GENERIC_ALLOCATOR 1
#define CONFIG_OPENVSWITCH_MODULE 1
#define CONFIG_FB_SYSMEM_HELPERS_DEFERRED 1
#define CONFIG_LIBCRC32C 1
#define CONFIG_GENERIC_BUG 1
#define CONFIG_CRYPTO_SHA256 1
#define CONFIG_HAVE_FTRACE_MCOUNT_RECORD 1
#define CONFIG_WL18XX_MODULE 1
#define CONFIG_POSIX_TIMERS 1
#define CONFIG_INET_TCP_DIAG 1
#define CONFIG_HOTPLUG_CORE_SYNC_DEAD 1
#define CONFIG_HW_CONSOLE 1
#define CONFIG_ZYNQMP_FIRMWARE_SECURE 1
#define CONFIG_RAS 1
#define CONFIG_USB_ETH_EEM 1
#define CONFIG_SMSC_PHY 1
#define CONFIG_DEVMEM 1
#define CONFIG_ARM_PMU 1
#define CONFIG_CRYPTO_LIB_SHA1 1
#define CONFIG_SND_SPI 1
#define CONFIG_ARCH_USES_PG_ARCH_X 1
#define CONFIG_JFFS2_FS_POSIX_ACL 1
#define CONFIG_HAVE_UID16 1
#define CONFIG_COMPAT_OLD_SIGACTION 1
#define CONFIG_PREEMPT_NONE_BUILD 1
#define CONFIG_IRQ_MSI_IOMMU 1
#define CONFIG_RTC_NVMEM 1
#define CONFIG_XILINX_TSN_QBR 1
#define CONFIG_BT_MRVL 1
#define CONFIG_QUOTACTL 1
#define CONFIG_V4L2_MEM2MEM_DEV 1
#define CONFIG_PARAVIRT 1
#define CONFIG_ZSTD_COMMON 1
#define CONFIG_HAVE_IOREMAP_PROT 1
#define CONFIG_BUILTIN_RETURN_ADDRESS_STRIPS_PAC 1
#define CONFIG_CC_HAS_KASAN_GENERIC 1
#define CONFIG_ZYNQMP_POWER 1
#define CONFIG_HAVE_ARM_SMCCC 1
#define CONFIG_DEBUG_KERNEL 1
#define CONFIG_LOCALVERSION "-xilinx"
#define CONFIG_ARCH_HAS_SYNC_DMA_FOR_CPU 1
#define CONFIG_GENERIC_IRQ_EFFECTIVE_AFF_MASK 1
#define CONFIG_ARCH_SUPPORTS_PAGE_TABLE_CHECK 1
#define CONFIG_RADIO_ADAPTERS 1
#define CONFIG_MEMTEST 1
#define CONFIG_CAN_RAW 1
#define CONFIG_SYMBOLIC_ERRNAME 1
#define CONFIG_CRYPTO 1
#define CONFIG_I2C_MUX_PCA954x 1
#define CONFIG_NET_VENDOR_BROCADE 1
#define CONFIG_BTRFS_FS 1
#define CONFIG_DEFAULT_MMAP_MIN_ADDR 32768
#define CONFIG_SYSTEM_TRUSTED_KEYS ""
#define CONFIG_IP_NF_IPTABLES 1
#define CONFIG_CMDLINE ""
#define CONFIG_VSOCKETS 1
#define CONFIG_BT_BNEP_PROTO_FILTER 1
#define CONFIG_XILINX_TSN_SWITCH 1
#define CONFIG_NET_VENDOR_QLOGIC 1
#define CONFIG_GCC10_NO_ARRAY_BOUNDS 1
#define CONFIG_RUNTIME_TESTING_MENU 1
#define CONFIG_VIDEOBUF2_DMA_CONTIG 1
#define CONFIG_USB_XHCI_HCD 1
#define CONFIG_VIRTIO 1
#define CONFIG_MMC_SDHCI_OF_ARASAN 1
#define CONFIG_VIDEO_XILINX_CRESAMPLE 1
#define CONFIG_HW_PERF_EVENTS 1
#define CONFIG_NET_SELFTESTS 1
#define CONFIG_ARM_CCI 1
#define CONFIG_DMA_VIRTUAL_CHANNELS 1
#define CONFIG_USB_ARCH_HAS_HCD 1
#define CONFIG_SERIAL_UARTLITE_RS485 1
#define CONFIG_GENERIC_IRQ_SHOW 1
#define CONFIG_NVMEM_SYSFS 1
#define CONFIG_HAVE_ARCH_JUMP_LABEL_RELATIVE 1
#define CONFIG_ARCH_HAS_ELF_RANDOMIZE 1
#define CONFIG_HAVE_FUNCTION_ARG_ACCESS_API 1
#define CONFIG_PANIC_ON_OOPS_VALUE 0
#define CONFIG_NET_VENDOR_SAMSUNG 1
#define CONFIG_NET_VENDOR_ADI 1
#define CONFIG_ARCH_INLINE_READ_LOCK_BH 1
#define CONFIG_INITRAMFS_PRESERVE_MTIME 1
#define CONFIG_SCSI_MOD 1
#define CONFIG_NET_VENDOR_MICREL 1
#define CONFIG_UBIFS_FS_XATTR 1
#define CONFIG_CRYPTO_CRC32C 1
#define CONFIG_VIDEO_XILINX_RGB2YUV 1
#define CONFIG_SERIAL_CORE 1
#define CONFIG_UID16 1
#define CONFIG_INLINE_WRITE_LOCK_BH 1
#define CONFIG_HAVE_KRETPROBES 1
#define CONFIG_ASSOCIATIVE_ARRAY 1
#define CONFIG_USB_GADGET_XILINX 1
#define CONFIG_NF_DEFRAG_IPV6 1
#define CONFIG_MICREL_PHY 1
#define CONFIG_VIDEO_DEV 1
#define CONFIG_MODULE_COMPRESS_NONE 1
#define CONFIG_CC_HAS_ZERO_CALL_USED_REGS 1
#define CONFIG_NFS_V4 1
#define CONFIG_CPU_FREQ_DEFAULT_GOV_USERSPACE 1
#define CONFIG_MAILBOX 1
#define CONFIG_INPUT_LEDS 1
#define CONFIG_RCU_NEED_SEGCBLIST 1
#define CONFIG_INLINE_READ_UNLOCK 1
#define CONFIG_CAN_XILINXCAN 1
#define CONFIG_ARCH_ZYNQMP 1
#define CONFIG_HAS_DMA 1
#define CONFIG_NF_CT_PROTO_SCTP 1
#define CONFIG_EDAC 1
#define CONFIG_USB_USB5744_MODULE 1
#define CONFIG_BROADCOM_PHY 1
#define CONFIG_SCSI 1
#define CONFIG_CC_HAVE_STACKPROTECTOR_SYSREG 1
#define CONFIG_ARCH_BINFMT_ELF_STATE 1
#define CONFIG_ARCH_INLINE_READ_LOCK_IRQSAVE 1
#define CONFIG_USB_OTG_FSM 1
#define CONFIG_ARM64_ERRATUM_1542419 1
#define CONFIG_HAVE_ARCH_THREAD_STRUCT_WHITELIST 1
#define CONFIG_HID 1
#define CONFIG_CC_HAS_BRANCH_PROT_PAC_RET 1
#define CONFIG_DMA_DECLARE_COHERENT 1
#define CONFIG_CGROUP_NET_PRIO 1
#define CONFIG_RANDOMIZE_BASE 1
#define CONFIG_USB_DWC3_DUAL_ROLE 1
#define CONFIG_DEVFREQ_GOV_SIMPLE_ONDEMAND 1
#define CONFIG_USB_ARMLINUX 1
#define CONFIG_LEDS_TRIGGER_DEFAULT_ON 1
#define CONFIG_VIDEO_XILINX_AXI4S_SWITCH 1
#define CONFIG_FONT_8x16 1
#define CONFIG_NET_VENDOR_MELLANOX 1
#define CONFIG_SERIAL_8250_FSL 1
#define CONFIG_VT_CONSOLE_SLEEP 1
#define CONFIG_ARCH_ENABLE_MEMORY_HOTPLUG 1
#define CONFIG_CRYPTO_USER_API_AEAD 1
#define CONFIG_FPGA_MGR_ZYNQMP_FPGA 1
#define CONFIG_ARCH_HAS_CURRENT_STACK_POINTER 1
#define CONFIG_PTP_1588_CLOCK 1
#define CONFIG_ARCH_HAS_CACHE_LINE_SIZE 1
#define CONFIG_JBD2 1
#define CONFIG_SPARSEMEM_VMEMMAP 1
#define CONFIG_MEMCG_KMEM 1
#define CONFIG_NET_VENDOR_MARVELL 1
#define CONFIG_PHYLIB 1
#define CONFIG_SND_SOC_XILINX_SPDIF 1
#define CONFIG_REGULATOR_GPIO 1
#define CONFIG_NET_VENDOR_NVIDIA 1
#define CONFIG_CRYPTO_SHA256_ARM64 1
#define CONFIG_IRQ_DOMAIN 1
#define CONFIG_VIRTIO_BALLOON 1
#define CONFIG_LOCALVERSION_AUTO 1
#define CONFIG_ARCH_HAS_DEBUG_VIRTUAL 1
#define CONFIG_JFFS2_RTIME 1
#define CONFIG_HAVE_ASM_MODVERSIONS 1
#define CONFIG_IPC_NS 1
#define CONFIG_CRYPTO_SHA512_ARM64 1
#define CONFIG_MISC_FILESYSTEMS 1
#define CONFIG_ARCH_MMAP_RND_BITS_MIN 18
#define CONFIG_ARCH_SUPPORTS_LTO_CLANG 1
#define CONFIG_DECOMPRESS_BZIP2 1
#define CONFIG_PER_VMA_LOCK 1
#define CONFIG_MHP_MEMMAP_ON_MEMORY 1
#define CONFIG_ARCH_SUPPORTS_UPROBES 1
#define CONFIG_EXPORTFS_BLOCK_OPS 1
#define CONFIG_NET_VENDOR_STMICRO 1
#define CONFIG_OF_DYNAMIC 1
#define CONFIG_V4L2_CCI 1
#define CONFIG_UIO_XILINX_APM 1
#define CONFIG_JFFS2_SUMMARY 1
#define CONFIG_ARCH_HAS_SYNC_DMA_FOR_DEVICE 1
#define CONFIG_OF_GPIO 1
#define CONFIG_ARCH_SUPPORTS_HUGETLBFS 1
#define CONFIG_INLINE_READ_UNLOCK_IRQ 1
#define CONFIG_SERIAL_MCTRL_GPIO 1
#define CONFIG_REALTEK_PHY 1
#define CONFIG_PROC_VMCORE 1
#define CONFIG_BT_HCIUART_QCA 1
#define CONFIG_IIO_ST_LSM6DSX_I3C 1
#define CONFIG_ARM64_ERRATUM_2441009 1
#define CONFIG_DST_CACHE 1
#define CONFIG_NF_REJECT_IPV6 1
#define CONFIG_RCU_CPU_STALL_TIMEOUT 21
#define CONFIG_POSIX_CPU_TIMERS_TASK_WORK 1
#define CONFIG_CHECKPOINT_RESTORE 1
#define CONFIG_SND_VERBOSE_PROCFS 1
#define CONFIG_XEN_NETDEV_FRONTEND 1
#define CONFIG_ARM64_ERRATUM_819472 1
#define CONFIG_LLD_VERSION 0
#define CONFIG_ARM64_ERRATUM_827319 1
#define CONFIG_NETFILTER_EGRESS 1
#define CONFIG_CAVIUM_TX2_ERRATUM_219 1
#define CONFIG_MDIO_DEVICE 1
#define CONFIG_NEED_SG_DMA_LENGTH 1
#define CONFIG_TIMER_PROBE 1
#define CONFIG_MODPROBE_PATH "/sbin/modprobe"
#define CONFIG_POWER_RESET 1
#define CONFIG_DRM_DISPLAY_HELPER 1
#define CONFIG_ARM64_EPAN 1
#define CONFIG_MACVLAN 1
#define CONFIG_WLCORE_SDIO_MODULE 1
#define CONFIG_PCIEASPM_DEFAULT 1
#define CONFIG_PROFILING 1
#define CONFIG_INTERVAL_TREE 1
#define CONFIG_NET_VENDOR_AMAZON 1
#define CONFIG_SPARSEMEM 1
#define CONFIG_DRM_GEM_SHMEM_HELPER 1
#define CONFIG_WLAN_VENDOR_ATMEL 1
#define CONFIG_NET_VENDOR_HISILICON 1
#define CONFIG_GRACE_PERIOD 1
#define CONFIG_NET_VENDOR_TEHUTI 1
#define CONFIG_XILINX_ZYNQMP_DPDMA 1
#define CONFIG_KEYBOARD_GPIO_POLLED 1
#define CONFIG_CRYPTO_MANAGER 1
#define CONFIG_ARCH_HAS_SUBPAGE_FAULTS 1
#define CONFIG_EEPROM_AT24 1
#define CONFIG_EDAC_SUPPORT 1
#define CONFIG_RT_MUTEXES 1
#define CONFIG_LOCK_SPIN_ON_OWNER 1
#define CONFIG_WLCORE_MODULE 1
#define CONFIG_NVIDIA_CARMEL_CNP_ERRATUM 1
#define CONFIG_PCI_SYSCALL 1
#define CONFIG_CC_NO_ARRAY_BOUNDS 1
#define CONFIG_HUGETLBFS 1
#define CONFIG_SLAB_MERGE_DEFAULT 1
#define CONFIG_KERNFS 1
#define CONFIG_CXD2880_SPI_DRV_MODULE 1
#define CONFIG_XILINX_TSN_PTP 1
#define CONFIG_MMC_BLOCK 1
#define CONFIG_PAGE_COUNTER 1
#define CONFIG_IOMMU_DEFAULT_DMA_STRICT 1
#define CONFIG_EXPERT 1
#define CONFIG_LXT_PHY 1
#define CONFIG_CFG80211_CRDA_SUPPORT 1
#define CONFIG_WIRELESS 1
#define CONFIG_WEXT_PROC 1
#define CONFIG_CRYPTO_AES_ARM64_CE_BLK 1
#define CONFIG_RPMSG_CTRL_MODULE 1
#define CONFIG_HZ_250 1
#define CONFIG_ARCH_HAS_STRICT_KERNEL_RWX 1
#define CONFIG_LOCK_DEBUGGING_SUPPORT 1
#define CONFIG_BT_HCIBTUSB 1
#define CONFIG_PKCS7_MESSAGE_PARSER 1
#define CONFIG_XILINX_PR_DECOUPLER 1
#define CONFIG_IRQ_SIM 1
#define CONFIG_TASK_IO_ACCOUNTING 1
#define CONFIG_NF_LOG_SYSLOG 1
#define CONFIG_FAT_DEFAULT_IOCHARSET "iso8859-1"
#define CONFIG_ARCH_INLINE_SPIN_UNLOCK_IRQRESTORE 1
#define CONFIG_USB_CONFIGFS_MASS_STORAGE 1
#define CONFIG_FRAME_WARN 2048
#define CONFIG_NET_VENDOR_AGERE 1
#define CONFIG_USB_NET_CDC_NCM 1
#define CONFIG_UVC_COMMON 1
#define CONFIG_HID_GENERIC 1
#define CONFIG_ARCH_MMAP_RND_BITS 18
#define CONFIG_QCOM_FALKOR_ERRATUM_E1041 1
#define CONFIG_BCM87XX_PHY 1
#define CONFIG_USB_ETH_MODULE 1
#define CONFIG_ARM64_ERRATUM_1530923 1
#define CONFIG_GENERIC_HWEIGHT 1
#define CONFIG_INITRAMFS_SOURCE ""
#define CONFIG_RTL_CARDS_MODULE 1
#define CONFIG_ARCH_MHP_MEMMAP_ON_MEMORY_ENABLE 1
#define CONFIG_CGROUPS 1
#define CONFIG_VIDEO_XILINX_SWITCH 1
#define CONFIG_MMC 1
#define CONFIG_LZO_COMPRESS 1
#define CONFIG_VIRTIO_INPUT_MODULE 1
#define CONFIG_HAVE_ARCH_MMAP_RND_COMPAT_BITS 1
#define CONFIG_DRM_VIRTIO_GPU_KMS 1
#define CONFIG_HAVE_GCC_PLUGINS 1
#define CONFIG_STACKTRACE 1
#define CONFIG_HAVE_PCI 1
#define CONFIG_EXTCON 1
#define CONFIG_AUDIT_COMPAT_GENERIC 1
#define CONFIG_GPIO_TPS65086 1
#define CONFIG_BMG160 1
#define CONFIG_ARCH_SUPPORTS_DEBUG_PAGEALLOC 1
#define CONFIG_HAS_IOPORT 1
#define CONFIG_ARCH_INLINE_WRITE_LOCK_IRQSAVE 1
#define CONFIG_CC_HAS_SIGN_RETURN_ADDRESS 1
#define CONFIG_PHYLIB_LEDS 1
#define CONFIG_CRYPTO_DRBG 1
#define CONFIG_COMMON_CLK_SI570 1
#define CONFIG_OF_EARLY_FLATTREE 1
#define CONFIG_WLAN_VENDOR_ADMTEK 1
#define CONFIG_CGROUP_CPUACCT 1
#define CONFIG_CAN_BCM 1
#define CONFIG_HAS_IOPORT_MAP 1
#define CONFIG_HAVE_FAST_GUP 1
#define CONFIG_VIRTIO_PCI_LIB 1
#define CONFIG_ARM64_PA_BITS 48
#define CONFIG_NET_VENDOR_VIA 1
#define CONFIG_UBIFS_FS_SECURITY 1
#define CONFIG_XEN_PCI_STUB 1
#define CONFIG_HZ 250
#define CONFIG_I2C_HELPER_AUTO 1
#define CONFIG_HISILICON_ERRATUM_161010101 1
#define CONFIG_INLINE_SPIN_UNLOCK_IRQ 1
#define CONFIG_SERIAL_8250_PERICOM 1
#define CONFIG_SERIAL_8250_NR_UARTS 4
#define CONFIG_ARCH_HAS_STRICT_MODULE_RWX 1
#define CONFIG_ARM64_WORKAROUND_CLEAN_CACHE 1
#define CONFIG_INLINE_READ_LOCK 1
#define CONFIG_CC_IS_GCC 1
#define CONFIG_DRM_XLNX_BRIDGE_CSC 1
#define CONFIG_BCM7XXX_PHY 1
#define CONFIG_DMA_OPS 1
#define CONFIG_NET_EGRESS 1
#define CONFIG_XEN_AUTO_XLATE 1
#define CONFIG_NET_VENDOR_ARC 1
#define CONFIG_VIDEO_XILINX_TPG 1
#define CONFIG_CRYPTO_ENGINE 1
#define CONFIG_AS_HAS_CFI_NEGATE_RA_STATE 1
#define CONFIG_RANDOMIZE_KSTACK_OFFSET 1
#define CONFIG_CRYPTO_SM4_ARM64_CE 1
#define CONFIG_MTD_UBI_BEB_LIMIT 20
#define CONFIG_MARVELL_PHY 1
#define CONFIG_HAVE_PERF_USER_STACK_DUMP 1
#define CONFIG_CGROUP_PERF 1
#define CONFIG_NLATTR 1
#define CONFIG_DMATEST 1
#define CONFIG_TCP_CONG_CUBIC 1
#define CONFIG_NR_CPUS 16
#define CONFIG_SUSPEND_FREEZER 1
#define CONFIG_ARM64_ERRATUM_1418040 1
#define CONFIG_MMC_SDHCI 1
#define CONFIG_SND_SUPPORT_OLD_API 1
#define CONFIG_NETFILTER_XT_CONNMARK 1
#define CONFIG_SOCIONEXT_SYNQUACER_PREITS 1
#define CONFIG_SYSFS 1
#define CONFIG_USB_DEFAULT_PERSIST 1
#define CONFIG_AS_HAS_NON_CONST_LEB128 1
#define CONFIG_EDAC_LEGACY_SYSFS 1
#define CONFIG_DRM_PANEL_BRIDGE 1
#define CONFIG_PCIE_XILINX_DMA_PL 1
#define CONFIG_ARM64_SVE 1
#define CONFIG_DVB_NET 1
#define CONFIG_BLK_DEV_BSG_COMMON 1
#define CONFIG_CAVIUM_ERRATUM_22375 1
#define CONFIG_ASN1 1
#define CONFIG_NETFILTER_XT_MATCH_LIMIT 1
#define CONFIG_CRYPTO_DEV_VIRTIO 1
#define CONFIG_VFIO_CDX 1
#define CONFIG_NET_KEY_MIGRATE 1
#define CONFIG_VIDEO_XILINX_CFA 1
#define CONFIG_USB_CONFIGFS_EEM 1
#define CONFIG_PTP_1588_CLOCK_OPTIONAL 1
#define CONFIG_FB_DMAMEM_HELPERS 1
#define CONFIG_CRYPTO_HASH_INFO 1
#define CONFIG_FB_SYS_FOPS 1
#define CONFIG_HAVE_SYSCALL_TRACEPOINTS 1
#define CONFIG_HAVE_ARCH_HUGE_VMALLOC 1
#define CONFIG_XILINX_PHY 1
#define CONFIG_IO_WQ 1
#define CONFIG_DECOMPRESS_ZSTD 1
#define CONFIG_PM_DEVFREQ 1
#define CONFIG_XILINX_EMACLITE 1
#define CONFIG_FB 1
#define CONFIG_BLK_MQ_VIRTIO 1
#define CONFIG_I2C_COMPAT 1
#define CONFIG_WLAN_VENDOR_ZYDAS 1
#define CONFIG_SPARSEMEM_VMEMMAP_ENABLE 1
#define CONFIG_LEDS_TRIGGER_CPU 1
#define CONFIG_ARM_GIC_V3 1
#define CONFIG_INLINE_READ_LOCK_IRQ 1
#define CONFIG_ARCH_SUPPORTS_KEXEC_SIG 1
#define CONFIG_MSDOS_PARTITION 1
#define CONFIG_INLINE_SPIN_LOCK_BH 1
#define CONFIG_RTC_I2C_AND_SPI 1
#define CONFIG_BT_HCIUART 1
#define CONFIG_ARM64_TLB_RANGE 1
#define CONFIG_HAVE_POSIX_CPU_TIMERS_TASK_WORK 1
#define CONFIG_ARM_PSCI_FW 1
#define CONFIG_LEGACY_DIRECT_IO 1
#define CONFIG_SYNC_FILE 1
#define CONFIG_USB_XHCI_PCI 1
#define CONFIG_CRYPTO_DEV_ZYNQMP_SHA3 1
#define CONFIG_IP_PNP_RARP 1
#define CONFIG_VETH 1
#define CONFIG_NET_VENDOR_3COM 1
#define CONFIG_STACKPROTECTOR 1
#define CONFIG_ARCH_ENABLE_SPLIT_PMD_PTLOCK 1
#define CONFIG_CMA_SIZE_MBYTES 256
#define CONFIG_HAVE_ARCH_KGDB 1
#define CONFIG_ARCH_USE_QUEUED_SPINLOCKS 1
#define CONFIG_BLK_DEBUG_FS 1
#define CONFIG_ARM_SCMI_HAVE_SHMEM 1
#define CONFIG_ARCH_HAS_ZONE_DMA_SET 1
#define CONFIG_VIDEOBUF2_V4L2 1
#define CONFIG_NET_VENDOR_INTEL 1
#define CONFIG_HAVE_SOFTIRQ_ON_OWN_STACK 1
#define CONFIG_ARM64_WORKAROUND_REPEAT_TLBI 1
#define CONFIG_RPS 1
#define CONFIG_PACKET_DIAG 1
#define CONFIG_USB_NET_ZAURUS 1
#define CONFIG_SERIAL_8250_EXAR 1
#define CONFIG_PROC_PID_CPUSET 1
#define CONFIG_USB_NET_AX88179_178A 1
#define CONFIG_PM_GENERIC_DOMAINS 1
#define CONFIG_LEGACY_PTY_COUNT 256
#define CONFIG_GENERIC_CSUM 1
#define CONFIG_MTD_MAP_BANK_WIDTH_2 1
#define CONFIG_GENERIC_IDLE_POLL_SETUP 1
#define CONFIG_SERIAL_MAX310X 1
#define CONFIG_ZISOFS 1
#define CONFIG_WLAN_VENDOR_MEDIATEK 1
#define CONFIG_IP_MULTICAST 1
#define CONFIG_NET_VENDOR_CISCO 1
#define CONFIG_ARCH_HAS_PTE_DEVMAP 1
#define CONFIG_BT_LEDS 1
#define CONFIG_TICK_ONESHOT 1
#define CONFIG_CRYPTO_CTR 1
#define CONFIG_AS_HAS_ARMV8_2 1
#define CONFIG_XARRAY_MULTI 1
#define CONFIG_LOCK_MM_AND_FIND_VMA 1
#define CONFIG_CGROUP_DEBUG 1
#define CONFIG_NATIONAL_PHY 1
#define CONFIG_HW_RANDOM 1
#define CONFIG_MUTEX_SPIN_ON_OWNER 1
#define CONFIG_BT_HCIBTUSB_RTL 1
#define CONFIG_SYS_HYPERVISOR 1
#define CONFIG_VIDEO_XILINX_SCALER 1
#define CONFIG_VIRTIO_VSOCKETS_COMMON 1
#define CONFIG_CGROUP_NET_CLASSID 1
#define CONFIG_HAVE_FUNCTION_GRAPH_TRACER 1
#define CONFIG_BUFFER_HEAD 1
#define CONFIG_ARM64_AMU_EXTN 1
#define CONFIG_OF_MDIO 1
#define CONFIG_HAVE_CMPXCHG_LOCAL 1
#define CONFIG_VIDEOBUF2_CORE 1
#define CONFIG_RANDOMIZE_MODULE_REGION_FULL 1
#define CONFIG_CRYPTO_BLAKE2B 1
#define CONFIG_TREE_SRCU 1
#define CONFIG_CRYPTO_NULL2 1
#define CONFIG_SERIAL_8250_DMA 1
#define CONFIG_FUNCTION_ALIGNMENT_4B 1
#define CONFIG_BASE_SMALL 0
#define CONFIG_XEN_GRANT_DEV_ALLOC_MODULE 1
#define CONFIG_VIDEO_CMDLINE 1
#define CONFIG_COMPACTION 1
#define CONFIG_NFS_V2 1
#define CONFIG_BLK_CGROUP_PUNT_BIO 1
#define CONFIG_PROC_FS 1
#define CONFIG_MTD_BLOCK 1
#define CONFIG_CRYPTO_USER_API_ENABLE_OBSOLETE 1
#define CONFIG_XILINX_TSN_QBV 1
#define CONFIG_VIDEOBUF2_VMALLOC 1
#define CONFIG_GENERIC_BUG_RELATIVE_POINTERS 1
#define CONFIG_MMU_GATHER_RCU_TABLE_FREE 1
#define CONFIG_VIRTIO_MMIO 1
#define CONFIG_NET_VENDOR_ROCKER 1
#define CONFIG_SCSI_LOWLEVEL 1
#define CONFIG_MTD_NAND_ARASAN 1
#define CONFIG_MEMFD_CREATE 1
#define CONFIG_IRQ_FORCED_THREADING 1
#define CONFIG_ARM64_CONT_PTE_SHIFT 4
#define CONFIG_XEN_SYS_HYPERVISOR 1
#define CONFIG_CRYPTO_CMAC 1
#define CONFIG_DRM_FBDEV_EMULATION 1
#define CONFIG_SND 1
#define CONFIG_ARCH_HAVE_ELF_PROT 1
#define CONFIG_XEN_NETDEV_BACKEND_MODULE 1
#define CONFIG_XEN_BALLOON 1
#define CONFIG_ARCH_USE_GNU_PROPERTY 1
#define CONFIG_USB_F_OBEX_MODULE 1
#define CONFIG_TCG_TIS_SPI 1
#define CONFIG_LD_ORPHAN_WARN 1
#define CONFIG_V4L_PLATFORM_DRIVERS 1
#define CONFIG_RFKILL_INPUT 1
#define CONFIG_SENSORS_MAX20751 1
#define CONFIG_NET_VENDOR_NATSEMI 1
#define CONFIG_BLK_DEV_BSGLIB 1
#define CONFIG_USB_DWC3_HAPS 1
#define CONFIG_VIRTIO_PCI_LIB_LEGACY 1
#define CONFIG_USB_F_MASS_STORAGE 1
#define CONFIG_IKCONFIG 1
#define CONFIG_NET_VENDOR_GOOGLE 1
#define CONFIG_INLINE_READ_UNLOCK_IRQRESTORE 1
#define CONFIG_GENERIC_IRQ_MIGRATION 1
#define CONFIG_NET_VENDOR_NETRONOME 1
#define CONFIG_NFS_USE_KERNEL_DNS 1
#define CONFIG_DMA_ENGINE_RAID 1
#define CONFIG_ARCH_HAS_FORTIFY_SOURCE 1
#define CONFIG_GCC_VERSION 130300
#define CONFIG_I2C_CADENCE 1
#define CONFIG_CRYPTO_LIB_POLY1305_RSIZE 9
#define CONFIG_TRANS_TABLE 1
#define CONFIG_SYSCTL 1
#define CONFIG_ARCH_HAS_GCOV_PROFILE_ALL 1
#define CONFIG_SND_USB_AUDIO_USE_MEDIA_CONTROLLER 1
#define CONFIG_BRIDGE_IGMP_SNOOPING 1
#define CONFIG_PHYS_ADDR_T_64BIT 1
#define CONFIG_THREAD_INFO_IN_TASK 1
#define CONFIG_USB_DWC3_ULPI 1
#define CONFIG_AHCI_CEVA 1
#define CONFIG_NET_VENDOR_LITEX 1
#define CONFIG_HAVE_C_RECORDMCOUNT 1
#define CONFIG_GENERIC_MSI_IRQ 1
#define CONFIG_HAVE_ARCH_TRACEHOOK 1
#define CONFIG_RPMSG_CHAR_MODULE 1
#define CONFIG_PCI_DOMAINS_GENERIC 1
#define CONFIG_DRM_FBDEV_OVERALLOC 100
#define CONFIG_XFRM_USER 1
#define CONFIG_I3C 1
#define CONFIG_CPUFREQ_DT_PLATDEV 1
#define CONFIG_ZYNQMP_FIRMWARE 1
#define CONFIG_TASK_DELAY_ACCT 1
#define CONFIG_ARCH_HAS_NON_OVERLAPPING_ADDRESS_SPACE 1
#define CONFIG_NET_NS 1
#define CONFIG_HAVE_PERF_EVENTS 1
#define CONFIG_VIDEO_XILINX 1
#define CONFIG_VFIO_CONTAINER 1
#define CONFIG_HAVE_ALIGNED_STRUCT_PAGE 1
#define CONFIG_NET_VENDOR_SOLARFLARE 1
#define CONFIG_CAN_GW 1
#define CONFIG_CRAMFS 1
#define CONFIG_LEDS_TRIGGER_TRANSIENT 1
#define CONFIG_AUDIT 1
#define CONFIG_KERNEL_MODE_NEON 1
#define CONFIG_BCH 1
#define CONFIG_V4L2_CCI_I2C 1
#define CONFIG_CRYPTO_USER_API_SKCIPHER 1
#define CONFIG_NET_9P_FD 1
#define CONFIG_CMA_AREAS 7
#define CONFIG_LTO_NONE 1
#define CONFIG_PCIEASPM 1
#define CONFIG_DEBUG_FS_ALLOW_ALL 1
#define CONFIG_ARM_GIC_MAX_NR 1
#define CONFIG_INLINE_SPIN_LOCK_IRQ 1
#define CONFIG_FB_DEFERRED_IO 1
#define CONFIG_PINCTRL_ZYNQMP 1
#define CONFIG_XEN_BALLOON_MEMORY_HOTPLUG 1
#define CONFIG_BLK_CGROUP_RWSTAT 1
#define CONFIG_MAX_SKB_FRAGS 17
#define CONFIG_SND_TIMER 1
#define CONFIG_FAT_DEFAULT_CODEPAGE 437
#define CONFIG_BLK_DEV 1
#define CONFIG_MAC80211_RC_DEFAULT "minstrel_ht"
#define CONFIG_NFS_ACL_SUPPORT 1
#define CONFIG_CC_HAS_ASM_GOTO_TIED_OUTPUT 1
#define CONFIG_OF_FLATTREE 1
#define CONFIG_HAVE_ARCH_KFENCE 1
#define CONFIG_WLAN_VENDOR_SILABS 1
#define CONFIG_IOMMU_API 1
#define CONFIG_TRACING_SUPPORT 1
#define CONFIG_UNIX98_PTYS 1
#define CONFIG_VFIO 1
#define CONFIG_NET_RX_BUSY_POLL 1
#define CONFIG_NET_VENDOR_SOCIONEXT 1
#define CONFIG_ZONE_DMA32 1
#define CONFIG_NET_SCHED 1
#define CONFIG_REGULATOR_TPS65086 1
#define CONFIG_ARCH_SUPPORTS_KEXEC 1
#define CONFIG_DRM_PANEL 1
#define CONFIG_PRINTK_TIME 1
#define CONFIG_TRACE_IRQFLAGS_NMI_SUPPORT 1
#define CONFIG_SECCOMP_FILTER 1
#define CONFIG_IRQCHIP 1
#define CONFIG_TI_ST 1
#define CONFIG_INET_DIAG 1
#define CONFIG_CRYPTO_GHASH 1
#define CONFIG_OVERLAY_FS_REDIRECT_ALWAYS_FOLLOW 1
#define CONFIG_NF_NAT_FTP_MODULE 1
#define CONFIG_MAC80211_RC_MINSTREL 1
#define CONFIG_IIO_CONSUMERS_PER_TRIGGER 2
#define CONFIG_NF_CT_PROTO_UDPLITE 1
#define CONFIG_IKCONFIG_PROC 1
#define CONFIG_ELF_CORE 1
#define CONFIG_DEV_COREDUMP 1
#define CONFIG_PCI_HOST_COMMON 1
#define CONFIG_SCSI_UFS_AMD_VERSAL2 1
#define CONFIG_USB_DWC3 1
#define CONFIG_HAVE_CONTEXT_TRACKING_USER 1
#define CONFIG_INA2XX_ADC 1
#define CONFIG_USB_SUPPORT 1
#define CONFIG_BMC150_MAGN_SPI 1
#define CONFIG_WLAN_VENDOR_ST 1
#define CONFIG_ARM_SCMI_POWER_DOMAIN 1
#define CONFIG_SOC_BUS 1
#define CONFIG_SPI_ZYNQMP_GQSPI 1
#define CONFIG_XEN_PVCALLS_BACKEND 1
#define CONFIG_STAGING 1
#define CONFIG_NET_VENDOR_SIS 1
#define CONFIG_CC_HAS_AUTO_VAR_INIT_ZERO_BARE 1
#define CONFIG_DMA_CMA 1
#define CONFIG_VIDEO_XILINX_AXI4S_SUBSETCONV 1
#define CONFIG_PAGE_POOL 1
#define CONFIG_SERIAL_8250_16550A_VARIANTS 1
#define CONFIG_CRYPTO_SM4 1
#define CONFIG_INIT_STACK_ALL_ZERO 1
#define CONFIG_ARM64_ERRATUM_2966298 1
#define CONFIG_VT_CONSOLE 1
#define CONFIG_HW_RANDOM_VIRTIO 1
#define CONFIG_LEDS_GPIO 1
#define CONFIG_SCHED_INFO 1
#define CONFIG_MQ_IOSCHED_KYBER 1
#define CONFIG_AS_VERSION 24200
#define CONFIG_DRM_XLNX_BRIDGE_DEBUG_FS 1
#define CONFIG_CC_HAS_INT128 1
#define CONFIG_EFI_EARLYCON 1
#define CONFIG_XILINX_WATCHDOG 1
#define CONFIG_CFG80211_WEXT 1
#define CONFIG_VIRTIO_VSOCKETS 1
#define CONFIG_WLAN_VENDOR_MARVELL 1
#define CONFIG_AUDIT_ARCH_COMPAT_GENERIC 1
#define CONFIG_CC_OPTIMIZE_FOR_PERFORMANCE 1
#define CONFIG_ARM64_CONT_PMD_SHIFT 4
#define CONFIG_BLK_DEV_RAM 1
#define CONFIG_ARCH_MMAP_RND_COMPAT_BITS 11
#define CONFIG_NETFILTER_XT_MATCH_STATE_MODULE 1
#define CONFIG_IIO_TRIGGERED_BUFFER 1
#define CONFIG_MFD_TPS65086 1
#define CONFIG_OPENVSWITCH_VXLAN_MODULE 1
#define CONFIG_INLINE_WRITE_UNLOCK_IRQRESTORE 1
#define CONFIG_DRM 1
#define CONFIG_DMABUF_HEAPS_SYSTEM 1
#define CONFIG_MEDIA_RADIO_SUPPORT 1
#define CONFIG_POSIX_MQUEUE_SYSCTL 1
#define CONFIG_ARM64 1
#define CONFIG_VHOST_MENU 1
#define CONFIG_XILINX_GMII2RGMII 1
#define CONFIG_DEBUG_MISC 1
#define CONFIG_USB_F_ECM 1
#define CONFIG_USB_ULPI_BUS 1
#define CONFIG_NET_VENDOR_MICROSEMI 1
#define CONFIG_BALLOON_COMPACTION 1
#define CONFIG_ARCH_HAS_TICK_BROADCAST 1
#define CONFIG_VFIO_GROUP 1
#define CONFIG_ZSTD_DECOMPRESS 1
#define CONFIG_ARM64_ERRATUM_1165522 1
#define CONFIG_SYSFS_SYSCALL 1
#define CONFIG_WLAN_VENDOR_QUANTENNA 1
#define CONFIG_SND_PCM_TIMER 1
#define CONFIG_ARCH_HAS_SET_DIRECT_MAP 1
#define CONFIG_SYSVIPC_SYSCTL 1
#define CONFIG_WLAN_VENDOR_TI 1
#define CONFIG_DMA_SHARED_BUFFER 1
#define CONFIG_RTC_SYSTOHC 1
#define CONFIG_OF_ADDRESS 1
#define CONFIG_XLNX_SYNC 1
#define CONFIG_DECOMPRESS_GZIP 1
#define CONFIG_VIRTIO_MENU 1
#define CONFIG_VIRTIO_BLK 1
#define CONFIG_AX88796B_PHY 1
#define CONFIG_DECOMPRESS_LZO 1
#define CONFIG_CRYPTO_XXHASH 1
#define CONFIG_64BIT 1
#define CONFIG_QUOTA 1
#define CONFIG_PARTITION_PERCPU 1
#define CONFIG_MMC_SDHCI_PLTFM 1
#define CONFIG_I2C_CHARDEV 1
#define CONFIG_LLC 1
#define CONFIG_ARCH_USE_QUEUED_RWLOCKS 1
#define CONFIG_ARCH_KEEP_MEMBLOCK 1
#define CONFIG_REGMAP_MMIO 1
#define CONFIG_NETWORK_SECMARK 1
#define CONFIG_MEDIA_TEST_SUPPORT 1
#define CONFIG_GENERIC_CLOCKEVENTS_BROADCAST 1
#define CONFIG_POWER_SUPPLY_HWMON 1
#define CONFIG_SERIAL_8250_PCI 1
#define CONFIG_NFS_V4_1 1
#define CONFIG_ARCH_USE_CMPXCHG_LOCKREF 1
#define CONFIG_ARCH_WANT_FRAME_POINTERS 1
#define CONFIG_REGMAP 1
#define CONFIG_HAVE_MOD_ARCH_SPECIFIC 1
#define CONFIG_FB_NOTIFY 1
#define CONFIG_CAN_DEV 1
#define CONFIG_STRICT_MODULE_RWX 1
#define CONFIG_SND_SOC_XILINX_AUDIO_FORMATTER 1
#define CONFIG_INLINE_SPIN_TRYLOCK 1
#define CONFIG_XEN_SCSI_FRONTEND_MODULE 1
#define CONFIG_USB_USBNET 1
#define CONFIG_IIO_ST_LSM6DSX 1
#define CONFIG_USB_USB2244_MODULE 1
#define CONFIG_SYSCTL_EXCEPTION_TRACE 1
#define CONFIG_SERIAL_UARTLITE_NR_UARTS 16
#define CONFIG_SYSVIPC_COMPAT 1
#define CONFIG_GPIO_PCA953X 1
#define CONFIG_INPUT_XEN_KBDDEV_FRONTEND 1
#define CONFIG_FHANDLE 1
#define CONFIG_HAVE_SAMPLE_FTRACE_DIRECT_MULTI 1
#define CONFIG_WATCHDOG_OPEN_TIMEOUT 0
#define CONFIG_NEW_LEDS 1
#define CONFIG_CRYPTO_LIB_SHA256 1
#define CONFIG_SWAP 1
#define CONFIG_FW_CACHE 1
#define CONFIG_VIDEO_XILINX_SCD 1
#define CONFIG_USB_NET_CDC_SUBSET_ENABLE 1
#define CONFIG_ADIN_PHY 1
#define CONFIG_MAC80211_MODULE 1
#define CONFIG_STACKPROTECTOR_PER_TASK 1
#define CONFIG_BME680_I2C 1
#define CONFIG_SND_SOC_XILINX_I2S 1
#define CONFIG_NET_VENDOR_CAVIUM 1
#define CONFIG_GPIOLIB_IRQCHIP 1
#define CONFIG_BLK_DEV_SD 1
#define CONFIG_HISILICON_ERRATUM_161600802 1
#define CONFIG_NETFILTER_NETLINK 1
#define CONFIG_VITESSE_PHY 1
#define CONFIG_MODULE_UNLOAD 1
#define CONFIG_NET_VENDOR_ENGLEDER 1
#define CONFIG_BT_LE 1
#define CONFIG_CMA 1
#define CONFIG_RWSEM_SPIN_ON_OWNER 1
#define CONFIG_ARM_GIC_V3_ITS_PCI 1
#define CONFIG_SND_SOC_XILINX_PL_SND_CARD 1
#define CONFIG_GPIO_PCA9570 1
#define CONFIG_CC_HAS_ASM_GOTO_OUTPUT 1
#define CONFIG_BITREVERSE 1
#define CONFIG_DEVPORT 1
#define CONFIG_IOSCHED_BFQ 1
#define CONFIG_MACB_USE_HWSTAMP 1
#define CONFIG_X509_CERTIFICATE_PARSER 1
#define CONFIG_BLK_DEV_RAM_SIZE 65536
#define CONFIG_ARCH_HAVE_TRACE_MMIO_ACCESS 1
#define CONFIG_REGMAP_I3C 1
#define CONFIG_PTP_1588_CLOCK_KVM 1
#define CONFIG_IIO_ST_LSM6DSX_SPI 1
#define CONFIG_NF_CONNTRACK 1
#define CONFIG_EFI_RUNTIME_WRAPPERS 1
#define CONFIG_MDIO_DEVRES 1
#define CONFIG_LSM "landlock,lockdown,yama,loadpin,safesetid,bpf"
#define CONFIG_ARCH_DMA_ADDR_T_64BIT 1
#define CONFIG_FILE_LOCKING 1
#define CONFIG_SND_SOC_I2C_AND_SPI 1
#define CONFIG_MAC80211_MESSAGE_TRACING 1
#define CONFIG_AIO 1
#define CONFIG_ARCH_INLINE_READ_UNLOCK_BH 1
#define CONFIG_NET_MPLS_GSO_MODULE 1
#define CONFIG_OF 1
#define CONFIG_PERF_EVENTS 1
#define CONFIG_GENERIC_TIME_VSYSCALL 1
#define CONFIG_IP_NF_TARGET_REJECT_MODULE 1
#define CONFIG_HAVE_MOVE_PMD 1
#define CONFIG_IOMMU_IO_PGTABLE 1
#define CONFIG_LEDS_CLASS 1
#define CONFIG_KALLSYMS_BASE_RELATIVE 1
#define CONFIG_ARCH_INLINE_READ_UNLOCK_IRQRESTORE 1
#define CONFIG_AS_HAS_LSE_ATOMICS 1
#define CONFIG_RTC_INTF_DEV 1
#define CONFIG_MTD_MAP_BANK_WIDTH_4 1
#define CONFIG_AS_HAS_SHA3 1
#define CONFIG_FUJITSU_ERRATUM_010001 1
#define CONFIG_CRYPTO_AES_ARM64_BS 1
#define CONFIG_HID_SUPPORT 1
#define CONFIG_DCACHE_WORD_ACCESS 1
#define CONFIG_CPU_LITTLE_ENDIAN 1
#define CONFIG_MAGIC_SYSRQ_SERIAL_SEQUENCE ""
#define CONFIG_MESSAGE_LOGLEVEL_DEFAULT 4
#define CONFIG_QSEMI_PHY 1
#define CONFIG_CMA_ALIGNMENT 8
#define CONFIG_VIDEO_CAMERA_SENSOR 1
#define CONFIG_NLS_DEFAULT "iso8859-1"
#define CONFIG_UTS_NS 1
#define CONFIG_VIDEO_NOMODESET 1
#define CONFIG_PAGE_REPORTING 1
#define CONFIG_BT_HCIUART_BCSP 1
#define CONFIG_COMMON_CLK_SI5324 1
#define CONFIG_NF_CT_NETLINK 1
#define CONFIG_DMA_ENGINE 1
#define CONFIG_CGROUP_PIDS 1
#define CONFIG_CRYPTO_AEAD2 1
#define CONFIG_QCOM_QDF2400_ERRATUM_0065 1
#define CONFIG_ARM64_E0PD 1
#define CONFIG_CRYPTO_ALGAPI2 1
#define CONFIG_UBIFS_FS_LZO 1
#define CONFIG_HAVE_EFFICIENT_UNALIGNED_ACCESS 1
#define CONFIG_INPUT 1
#define CONFIG_PROC_SYSCTL 1
#define CONFIG_FWNODE_MDIO 1
#define CONFIG_ARM_SCMI_TRANSPORT_SMC 1
#define CONFIG_RD_LZ4 1
#define CONFIG_INLINE_READ_UNLOCK_BH 1
#define CONFIG_CPU_MITIGATIONS 1
#define CONFIG_MMU 1
#define CONFIG_LD_VERSION 24200
#define CONFIG_INA260_ADC 1
#define CONFIG_HAVE_HARDLOCKUP_DETECTOR_BUDDY 1
#define CONFIG_INLINE_WRITE_UNLOCK 1
#define CONFIG_KUSER_HELPERS 1
