#ifndef __DT_BINDINGS_DRM__
#define __DT_BINDINGS_DRM__
/*
 * MIPI DSI pixel formats as defined in the include/drm/drm_mipi_dsi.h"
 */
#define MIPI_DSI_FMT_RGB888		0
#define MIPI_DSI_FMT_RGB666		1
#define MIPI_DSI_FMT_RGB666_PACKED	2
#define MIPI_DSI_FMT_RGB565		3

#endif /* _DT_BINDINGS_DRM__ */
