/* SPDX-License-Identifier: (GPL-2.0-only OR BSD-2-Clause) */
/*
 * Author: Yinbo Zhu <zhuyinbo@loongson.cn>
 * Copyright (C) 2022-2023 Loongson Technology Corporation Limited
 */

#ifndef __DT_BINDINGS_CLOCK_LOONGSON2_H
#define __DT_BINDINGS_CLOCK_LOONGSON2_H

#define LOONGSON2_REF_100M				0
#define LOONGSON2_NODE_PLL				1
#define LOONGSON2_DDR_PLL				2
#define LOONGSON2_DC_PLL				3
#define LOONGSON2_PIX0_PLL				4
#define LOONGSON2_PIX1_PLL				5
#define LOONGSON2_NODE_CLK				6
#define LOONGSON2_HDA_CLK				7
#define LOONGSON2_GPU_CLK				8
#define LOONGSON2_DDR_CLK				9
#define LOONGSON2_GMAC_CLK				10
#define LOONGSON2_DC_CLK				11
#define LOONGSON2_APB_CLK				12
#define LOONGSON2_USB_CLK				13
#define LOONGSON2_SATA_CLK				14
#define LOONGSON2_PIX0_CLK				15
#define LOONGSON2_PIX1_CLK				16
#define LOONGSON2_BOOT_CLK				17
#define LOONGSON2_CLK_END				18

#endif
