/* SPDX-License-Identifier: (GPL-2.0+ OR MIT) */

#ifndef _DT_BINDINGS_CLK_SUN6I_RTC_H_
#define _DT_BINDINGS_CLK_SUN6I_RTC_H_

#define CLK_OSC32K		0
#define CLK_OSC32K_FANOUT	1
#define CLK_IOSC		2

#endif /* _DT_BINDINGS_CLK_SUN6I_RTC_H_ */
